/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { EventEmitter, OnChanges, OnDestroy, SimpleChanges } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { ChartWizardDataRow, ChartWizardInitialState } from './chart-wizard-state';
import { StateService } from './state.service';
import { ChartComponent } from '@progress/kendo-angular-charts';
import { ChartWizardPropertyPaneDataTabComponent } from './property-pane/data-tab.component';
import { ChartWizardPropertyPaneChartTabComponent } from './property-pane/chart-tab.component';
import { ExportEvent } from './events';
import { ExportOptions } from './common/models';
import { WindowSettings } from './common/window-settings';
import * as i0 from "@angular/core";
/**
 * Represents the Kendo UI for Angular Chart Wizard component.
 *
 * @example
 * ```html
 *  <kendo-chartwizard [data]="data"></kendo-chartwizard>
 * ```
 */
export declare class ChartWizardComponent implements OnChanges, OnDestroy {
    private localization;
    stateService: StateService;
    /**
     * The data to display in the Chart Wizard.
     */
    data: ChartWizardDataRow[];
    /**
     * Sets the default state of the Chart Wizard.
     */
    defaultState: ChartWizardInitialState;
    /**
     * The Chart Wizard export options.
     */
    exportOptions: ExportOptions;
    /**
     * Specifies if the configuration pane is initially collapsed.
     * @default false
     */
    collapsedConfigurationPane: boolean;
    /**
     * The settings of the window.
     */
    windowSettings: WindowSettings;
    /**
     * @hidden
     */
    showLicenseWatermark: boolean;
    /**
     * @hidden
     */
    exportIcon: import("@progress/kendo-svg-icons").SVGIcon;
    /**
     * @hidden
     */
    exportDropdownItems: any[];
    /**
     * Fires when the Chart Wizard Window is to be close.
     */
    close: EventEmitter<any>;
    /**
     * Fires when the Chart is about to be exported. The event is preventable.
     */
    export: EventEmitter<ExportEvent>;
    get dir(): string;
    /**
     * @hidden
     */
    chart: ChartComponent;
    /**
     * @hidden
     */
    propertyPane: ChartWizardPropertyPaneChartTabComponent;
    /**
     * @hidden
     */
    dataTab: ChartWizardPropertyPaneDataTabComponent;
    /**
     * @hidden
     */
    messages: {
        readonly windowTitle: string;
        readonly exportButton: string;
        readonly exportPDFButton: string;
        readonly exportSVGButton: string;
        readonly exportPNGButton: string;
        readonly tabChart: string;
        readonly tabData: string;
        readonly tabFormat: string;
        readonly barChart: string;
        readonly barChartBar: string;
        readonly barChartStackedBar: string;
        readonly barChart100StackedBar: string;
        readonly pieChart: string;
        readonly pieChartPie: string;
        readonly columnChart: string;
        readonly columnChartColumn: string;
        readonly columnChartStackedColumn: string;
        readonly columnChart100StackedColumn: string;
        readonly lineChart: string;
        readonly lineChartLine: string;
        readonly lineChartStackedLine: string;
        readonly lineChart100StackedLine: string;
        readonly scatterChart: string;
        readonly scatterChartScatter: string;
        readonly configuration: string;
        readonly configurationCategoryAxis: string;
        readonly configurationXAxis: string;
        readonly configurationValueAxis: string;
        readonly configurationSeries: string;
        readonly configurationSeriesAdd: string;
        readonly formatChartArea: string;
        readonly formatChartAreaMargins: string;
        readonly formatChartAreaMarginsAuto: string;
        readonly formatChartAreaMarginsLeft: string;
        readonly formatChartAreaMarginsRight: string;
        readonly formatChartAreaMarginsTop: string;
        readonly formatChartAreaMarginsBottom: string;
        readonly formatChartAreaBackground: string;
        readonly formatChartAreaBackgroundColor: string;
        readonly formatTitle: string;
        readonly formatTitleApplyTo: string;
        readonly formatTitleChartTitle: string;
        readonly formatTitleChartSubtitle: string;
        readonly formatTitleLabel: string;
        readonly formatTitleFont: string;
        readonly formatTitleFontPlaceholder: string;
        readonly formatTitleSize: string;
        readonly formatTitleSizePlaceholder: string;
        readonly formatTitleColor: string;
        readonly formatSeries: string;
        readonly formatSeriesApplyTo: string;
        readonly formatSeriesAllSeries: string;
        readonly formatSeriesColor: string;
        readonly formatSeriesShowLabels: string;
        readonly formatLegend: string;
        readonly formatLegendShowLegend: string;
        readonly formatLegendFont: string;
        readonly formatLegendFontPlaceholder: string;
        readonly formatLegendSize: string;
        readonly formatLegendSizePlaceholder: string;
        readonly formatLegendColor: string;
        readonly formatLegendPosition: string;
        readonly formatLegendPositionTop: string;
        readonly formatLegendPositionBottom: string;
        readonly formatLegendPositionLeft: string;
        readonly formatLegendPositionRight: string;
        readonly formatCategoryAxis: string;
        readonly formatXAxis: string;
        readonly formatCategoryAxisTitle: string;
        readonly formatCategoryAxisTitlePlaceholder: string;
        readonly formatCategoryAxisTitleFont: string;
        readonly formatCategoryAxisTitleFontPlaceholder: string;
        readonly formatCategoryAxisTitleSize: string;
        readonly formatCategoryAxisTitleSizePlaceholder: string;
        readonly formatCategoryAxisTitleColor: string;
        readonly formatCategoryAxisLabels: string;
        readonly formatCategoryAxisLabelsFont: string;
        readonly formatCategoryAxisLabelsFontPlaceholder: string;
        readonly formatCategoryAxisLabelsSize: string;
        readonly formatCategoryAxisLabelsSizePlaceholder: string;
        readonly formatCategoryAxisLabelsColor: string;
        readonly formatCategoryAxisLabelsRotation: string;
        readonly formatCategoryAxisLabelsRotationAuto: string;
        readonly formatCategoryAxisLabelsReverseOrder: string;
        readonly formatValueAxis: string;
        readonly formatYAxis: string;
        readonly formatValueAxisTitle: string;
        readonly formatValueAxisTitlePlaceholder: string;
        readonly formatValueAxisTitleFont: string;
        readonly formatValueAxisTitleFontPlaceholder: string;
        readonly formatValueAxisTitleSize: string;
        readonly formatValueAxisTitleSizePlaceholder: string;
        readonly formatValueAxisTitleColor: string;
        readonly formatValueAxisLabels: string;
        readonly formatValueAxisLabelsFormat: string;
        readonly formatValueAxisLabelsFormatText: string;
        readonly formatValueAxisLabelsFormatNumber: string;
        readonly formatValueAxisLabelsFormatCurrency: string;
        readonly formatValueAxisLabelsFormatPercent: string;
        readonly formatValueAxisLabelsFont: string;
        readonly formatValueAxisLabelsFontPlaceholder: string;
        readonly formatValueAxisLabelsSize: string;
        readonly formatValueAxisLabelsSizePlaceholder: string;
        readonly formatValueAxisLabelsColor: string;
        readonly formatValueAxisLabelsRotation: string;
        readonly formatValueAxisLabelsRotationAuto: string;
    };
    private subscription;
    constructor(localization: LocalizationService, stateService: StateService);
    ngAfterViewInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    messageFor(key: string): string;
    /**
     * @hidden
     */
    onExport(exportType: any): void;
    /**
     * @hidden
     */
    get windowWidth(): number;
    /**
     * @hidden
     */
    get windowHeight(): number;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChartWizardComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChartWizardComponent, "kendo-chartwizard", ["kendoChartWizard"], { "data": { "alias": "data"; "required": false; }; "defaultState": { "alias": "defaultState"; "required": false; }; "exportOptions": { "alias": "exportOptions"; "required": false; }; "collapsedConfigurationPane": { "alias": "collapsedConfigurationPane"; "required": false; }; "windowSettings": { "alias": "windowSettings"; "required": false; }; }, { "close": "close"; "export": "export"; }, never, never, true, never>;
}
