/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import * as i0 from '@angular/core';
import { Injectable, Inject, Optional, Component, ChangeDetectionStrategy, ViewEncapsulation, ViewChild, Input, EventEmitter, Output, HostBinding, Directive, forwardRef, HostListener, NgModule } from '@angular/core';
import { shouldShowValidationUI, isPresent, WatermarkOverlayComponent, ResizeBatchService } from '@progress/kendo-angular-common';
import * as i1 from '@progress/kendo-angular-l10n';
import { LocalizationService, L10N_PREFIX, RTL, ComponentMessages } from '@progress/kendo-angular-l10n';
import { validatePackage } from '@progress/kendo-licensing';
import { Subscription } from 'rxjs';
import { ChartWizardCommon } from '@progress/kendo-charts';
import { trashIcon, plusIcon, exportIcon, chartBarClusteredIcon, chartBarStackedIcon, chartBarStacked100Icon, chartPieIcon, chartColumnClusteredIcon, chartColumnStackedIcon, chartColumnStacked100Icon, chartLineIcon, chartLineStackedIcon, chartLineStacked100Icon, chartScatterIcon, filePdfIcon, fileIcon, fileImageIcon } from '@progress/kendo-svg-icons';
import { ChartComponent, TitleComponent, SubtitleComponent, ChartAreaComponent, CategoryAxisComponent, CategoryAxisItemComponent, ValueAxisComponent, ValueAxisItemComponent, SeriesComponent, SeriesItemComponent, LegendComponent, XAxisComponent, XAxisItemComponent, YAxisComponent, YAxisItemComponent, ThemeService } from '@progress/kendo-angular-charts';
import { saveAs } from '@progress/kendo-file-saver';
import { exportPDF } from '@progress/kendo-drawing';
import * as i2 from '@angular/forms';
import * as i1$1 from '@progress/kendo-angular-grid';
import { GridComponent, ReactiveEditingDirective, DataBindingDirective, ToolbarTemplateDirective, RowReorderColumnComponent, ColumnComponent, CommandColumnComponent, CellTemplateDirective, GridToolbarFocusableDirective, RemoveCommandDirective } from '@progress/kendo-angular-grid';
import { NgIf, NgFor } from '@angular/common';
import { ExpansionPanelComponent, SplitterComponent, SplitterPaneComponent, TabStripComponent, TabStripTabComponent, TabContentDirective } from '@progress/kendo-angular-layout';
import { DropDownListComponent, ComboBoxComponent } from '@progress/kendo-angular-dropdowns';
import { ButtonComponent, DropDownButtonComponent } from '@progress/kendo-angular-buttons';
import { SVGIconComponent, IconsService } from '@progress/kendo-angular-icons';
import { WindowComponent, DialogContainerService, DialogService, WindowService, WindowContainerService } from '@progress/kendo-angular-dialog';
import { NumericTextBoxComponent, ColorPickerComponent, TextBoxComponent, CheckBoxComponent, SwitchComponent } from '@progress/kendo-angular-inputs';
import { LabelComponent } from '@progress/kendo-angular-label';
import { trigger, state, style, transition, animate } from '@angular/animations';
import { PopupService } from '@progress/kendo-angular-popup';
import { getter } from '@progress/kendo-common';

/**
 * @hidden
 */
const packageMetadata = {
    name: '@progress/kendo-angular-chart-wizard',
    productName: 'Kendo UI for Angular',
    productCode: 'KENDOUIANGULAR',
    productCodes: ['KENDOUIANGULAR'],
    publishDate: 1749540427,
    version: '19.1.1',
    licensingDocsUrl: 'https://www.telerik.com/kendo-angular-ui/my-license/?utm_medium=product&utm_source=kendoangular&utm_campaign=kendo-ui-angular-purchase-license-keys-warning',
};

/**
 * @hidden
 */
const fontSizes = ChartWizardCommon.fontSizes;
/**
 * @hidden
 */
const fontNames = ChartWizardCommon.fontNames;
/**
 * @hidden
 */
const createState = ChartWizardCommon.createState;
/**
 * @hidden
 */
const updateState = ChartWizardCommon.updateState;
/**
 * @hidden
 */
const mergeStates = ChartWizardCommon.mergeStates;
/**
 * @hidden
 */
const isCategorical = ChartWizardCommon.isCategorical;
/**
 * @hidden
 */
const parseFont = ChartWizardCommon.parseFont;
/**
 * @hidden
 */
const ActionTypes = ChartWizardCommon.ActionTypes;
/**
 * @hidden
 */
const rotations = [
    { text: 'Auto', value: 'auto' },
    { text: '0°', value: 0 },
    { text: '45°', value: 45 },
    { text: '90°', value: 90 },
    { text: '135°', value: 135 },
    { text: '180°', value: 180 }
];
/**
 * @hidden
 */
const positions = [
    { text: 'Top', value: 'top' },
    { text: 'Bottom', value: 'bottom' },
    { text: 'Left', value: 'left' },
    { text: 'Right', value: 'right' }
];

/**
 * @hidden
 */
const defaultAllSeriesItem = { name: 'All Series' };
/**
 * @hidden
 */
const defaultFormat = {
    value: '',
    text: 'Text'
};
/**
 * @hidden
 */
const labelFormats = [
    defaultFormat,
    { value: 'n0', text: 'Number' },
    { value: 'c0', text: 'Currency' },
    { value: 'p0', text: 'Percent' }
];

/**
 * @hidden
 */
class StateService {
    state = {
        categoryAxis: [],
        valueAxis: [],
        series: [],
        initialSeries: [],
        columns: [],
        data: [],
        area: { margin: { top: 0, right: 0, bottom: 0, left: 0 } },
        seriesType: 'bar'
    };
    seriesType = 'bar';
    currentTitle = 'Chart Title';
    currentSeries = defaultAllSeriesItem;
    data = [];
    deletedSeries = [];
    direction = 'ltr';
    windowSize = { width: 700, height: 550 };
    splitterPaneSize = '300px';
    dataTab;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: StateService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: StateService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: StateService, decorators: [{
            type: Injectable
        }] });

/**
 * @hidden
 */
class ChartWizardLocalizationService extends LocalizationService {
    constructor(prefix, messageService, _rtl) {
        super(prefix, messageService, _rtl);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardLocalizationService, deps: [{ token: L10N_PREFIX }, { token: i1.MessageService, optional: true }, { token: RTL, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardLocalizationService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardLocalizationService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [L10N_PREFIX]
                }] }, { type: i1.MessageService, decorators: [{
                    type: Optional
                }] }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [RTL]
                }] }]; } });

/**
 * @hidden
 */
class ChartWizardPropertyPaneDataTabComponent {
    stateService;
    formBuilder;
    cdr;
    renderer;
    localization;
    categoryAxisX = ActionTypes.categoryAxisX;
    valueAxisY = ActionTypes.valueAxisY;
    trashIcon = trashIcon;
    plusIcon = plusIcon;
    isCategorical = isCategorical;
    grid;
    constructor(stateService, formBuilder, cdr, renderer, localization) {
        this.stateService = stateService;
        this.formBuilder = formBuilder;
        this.cdr = cdr;
        this.renderer = renderer;
        this.localization = localization;
        this.formGroup = this.formBuilder.group({
            name: null,
        });
    }
    ngAfterViewInit() {
        if (this.grid) {
            const gridHeader = this.grid.wrapper.nativeElement.querySelector('.k-grid .k-grid-header');
            const gridContent = this.grid.wrapper.nativeElement.querySelector('.k-grid .k-grid-content');
            this.renderer.setStyle(gridHeader, 'display', 'none');
            this.renderer.setStyle(gridContent, 'overflow', 'auto');
        }
    }
    updateState(action, value) {
        this.stateService.state = updateState(this.stateService.state, action, value);
    }
    formGroup;
    createFormGroup(args) {
        const item = args.isNew ? {} : args.dataItem;
        this.formGroup = this.formBuilder.group({
            name: item.name,
        });
        return this.formGroup;
    }
    addData() {
        this.stateService.state.series.push(this.stateService.deletedSeries[0]);
        this.stateService.deletedSeries.shift();
        this.updateState(ActionTypes.seriesChange, this.stateService.state.series);
    }
    removeData(event) {
        this.stateService.deletedSeries.push(event.dataItem);
        this.updateState(ActionTypes.seriesChange, event.sender.data.data);
    }
    onRowReorder(grid) {
        this.updateState(ActionTypes.seriesChange, grid.data.data);
    }
    isDisabled(grid) {
        return grid.data.data.length === this.stateService.state.initialSeries.length;
    }
    detectChanges() {
        this.cdr.detectChanges();
    }
    messageFor(key) {
        return this.localization.get(key);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardPropertyPaneDataTabComponent, deps: [{ token: StateService }, { token: i2.FormBuilder }, { token: i0.ChangeDetectorRef }, { token: i0.Renderer2 }, { token: ChartWizardLocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ChartWizardPropertyPaneDataTabComponent, isStandalone: true, selector: "kendo-chartwizard-property-pane-data-tab", viewQueries: [{ propertyName: "grid", first: true, predicate: GridComponent, descendants: true }], ngImport: i0, template: `
        <kendo-expansionpanel [title]="messageFor('configuration')" [expanded]="true">
            <form class="k-form k-form-md">
                <fieldset class="k-form-fieldset">
                    <legend class="k-form-legend">
                        {{ stateService.state.seriesType === 'scatter' ? messageFor('configurationXAxis') : messageFor('configurationCategoryAxis') }}
                    </legend>
                    <kendo-dropdownlist
                        [data]="stateService.state.columns"
                        [value]="stateService.state.categoryField"
                        (valueChange)="updateState(categoryAxisX, $event)"
                        fillMode="outline"
                        rounded="medium"
                        size="medium"
                    >
                    </kendo-dropdownlist>
                </fieldset>
                <fieldset class="k-form-fieldset" *ngIf="isCategorical(stateService.state.seriesType)">
                    <legend class="k-form-legend">{{ messageFor('configurationSeries') }}</legend>
                    <kendo-grid
                        #grid
                        [kendoGridReactiveEditing]="createFormGroup"
                        [kendoGridBinding]="stateService.state.series"
                        [rowReorderable]="true"
                        (rowReorder)="onRowReorder(grid)"
                        (remove)="removeData($event)"
                    >
                        <ng-template kendoGridToolbarTemplate>
                            <button
                                kendoButton
                                type="button"
                                [svgIcon]="plusIcon"
                                fillMode="flat"
                                rounded="medium"
                                [disabled]="isDisabled(grid)"
                                (click)="addData()"
                            >
                                {{ messageFor('configurationSeriesAdd') }}
                            </button>
                        </ng-template>
                        <kendo-grid-rowreorder-column [width]="40"></kendo-grid-rowreorder-column>
                        <kendo-grid-column field="name" title="">
                        </kendo-grid-column>
                        <kendo-grid-command-column [width]="40">
                            <ng-template kendoGridCellTemplate>
                                <button
                                    [svgIcon]="trashIcon"
                                    kendoGridRemoveCommand
                                    fillMode="flat"
                                    rounded="medium"
                                    [disabled]="stateService.state.series.length < 2"
                                ></button>
                            </ng-template>
                        </kendo-grid-command-column>
                    </kendo-grid>
                </fieldset>
                <fieldset
                    class="k-form-fieldset"
                    *ngIf="stateService.state.seriesType === 'pie'"
                >
                    <legend class="k-form-legend">
                        {{ messageFor('configurationValueAxis') }}
                    </legend>
                    <kendo-dropdownlist
                        [data]="stateService.state.columns"
                        [value]="stateService.state.valueField"
                        (valueChange)="updateState(valueAxisY, $event)"
                        fillMode="outline"
                        rounded="medium"
                        size="medium"
                    >
                    </kendo-dropdownlist>
                </fieldset>
            </form>
        </kendo-expansionpanel>
    `, isInline: true, dependencies: [{ kind: "component", type: ExpansionPanelComponent, selector: "kendo-expansionpanel", inputs: ["title", "subtitle", "disabled", "expanded", "svgExpandIcon", "svgCollapseIcon", "expandIcon", "collapseIcon", "animation"], outputs: ["expandedChange", "action", "expand", "collapse"], exportAs: ["kendoExpansionPanel"] }, { kind: "component", type: DropDownListComponent, selector: "kendo-dropdownlist", inputs: ["customIconClass", "showStickyHeader", "icon", "svgIcon", "loading", "data", "value", "textField", "valueField", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "defaultItem", "disabled", "itemDisabled", "readonly", "filterable", "virtual", "ignoreCase", "delay", "valuePrimitive", "tabindex", "tabIndex", "size", "rounded", "fillMode", "leftRightArrowsNavigation", "id"], outputs: ["valueChange", "filterChange", "selectionChange", "open", "opened", "close", "closed", "focus", "blur"], exportAs: ["kendoDropDownList"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: GridComponent, selector: "kendo-grid", inputs: ["data", "pageSize", "height", "rowHeight", "adaptiveMode", "detailRowHeight", "skip", "scrollable", "selectable", "sort", "size", "trackBy", "filter", "group", "virtualColumns", "filterable", "sortable", "pageable", "groupable", "gridResizable", "rowReorderable", "navigable", "autoSize", "rowClass", "rowSticky", "rowSelected", "isRowSelectable", "cellSelected", "resizable", "reorderable", "loading", "columnMenu", "hideHeader", "showInactiveTools", "isDetailExpanded", "isGroupExpanded"], outputs: ["filterChange", "pageChange", "groupChange", "sortChange", "selectionChange", "rowReorder", "dataStateChange", "gridStateChange", "groupExpand", "groupCollapse", "detailExpand", "detailCollapse", "edit", "cancel", "save", "remove", "add", "cellClose", "cellClick", "pdfExport", "excelExport", "columnResize", "columnReorder", "columnVisibilityChange", "columnLockedChange", "columnStickyChange", "scrollBottom", "contentScroll"], exportAs: ["kendoGrid"] }, { kind: "directive", type: ReactiveEditingDirective, selector: "[kendoGridReactiveEditing]", inputs: ["kendoGridReactiveEditing"] }, { kind: "directive", type: DataBindingDirective, selector: "[kendoGridBinding]", inputs: ["skip", "sort", "filter", "pageSize", "group", "kendoGridBinding"], exportAs: ["kendoGridBinding"] }, { kind: "directive", type: ToolbarTemplateDirective, selector: "[kendoGridToolbarTemplate]", inputs: ["position"] }, { kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }, { kind: "component", type: RowReorderColumnComponent, selector: "kendo-grid-rowreorder-column", inputs: ["dragHandleIcon", "dragHandleSVGIcon"] }, { kind: "component", type: ColumnComponent, selector: "kendo-grid-column", inputs: ["field", "format", "sortable", "groupable", "editor", "filter", "filterable", "editable"] }, { kind: "component", type: CommandColumnComponent, selector: "kendo-grid-command-column" }, { kind: "directive", type: CellTemplateDirective, selector: "[kendoGridCellTemplate]" }, { kind: "directive", type: GridToolbarFocusableDirective, selector: "        [kendoGridToolbarFocusable],        [kendoGridAddCommand],        [kendoGridCancelCommand],        [kendoGridEditCommand],        [kendoGridRemoveCommand],        [kendoGridSaveCommand],        [kendoGridExcelCommand],        [kendoGridPDFCommand]    " }, { kind: "component", type: RemoveCommandDirective, selector: "[kendoGridRemoveCommand]" }], changeDetection: i0.ChangeDetectionStrategy.OnPush, encapsulation: i0.ViewEncapsulation.None });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardPropertyPaneDataTabComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-chartwizard-property-pane-data-tab',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    encapsulation: ViewEncapsulation.None,
                    template: `
        <kendo-expansionpanel [title]="messageFor('configuration')" [expanded]="true">
            <form class="k-form k-form-md">
                <fieldset class="k-form-fieldset">
                    <legend class="k-form-legend">
                        {{ stateService.state.seriesType === 'scatter' ? messageFor('configurationXAxis') : messageFor('configurationCategoryAxis') }}
                    </legend>
                    <kendo-dropdownlist
                        [data]="stateService.state.columns"
                        [value]="stateService.state.categoryField"
                        (valueChange)="updateState(categoryAxisX, $event)"
                        fillMode="outline"
                        rounded="medium"
                        size="medium"
                    >
                    </kendo-dropdownlist>
                </fieldset>
                <fieldset class="k-form-fieldset" *ngIf="isCategorical(stateService.state.seriesType)">
                    <legend class="k-form-legend">{{ messageFor('configurationSeries') }}</legend>
                    <kendo-grid
                        #grid
                        [kendoGridReactiveEditing]="createFormGroup"
                        [kendoGridBinding]="stateService.state.series"
                        [rowReorderable]="true"
                        (rowReorder)="onRowReorder(grid)"
                        (remove)="removeData($event)"
                    >
                        <ng-template kendoGridToolbarTemplate>
                            <button
                                kendoButton
                                type="button"
                                [svgIcon]="plusIcon"
                                fillMode="flat"
                                rounded="medium"
                                [disabled]="isDisabled(grid)"
                                (click)="addData()"
                            >
                                {{ messageFor('configurationSeriesAdd') }}
                            </button>
                        </ng-template>
                        <kendo-grid-rowreorder-column [width]="40"></kendo-grid-rowreorder-column>
                        <kendo-grid-column field="name" title="">
                        </kendo-grid-column>
                        <kendo-grid-command-column [width]="40">
                            <ng-template kendoGridCellTemplate>
                                <button
                                    [svgIcon]="trashIcon"
                                    kendoGridRemoveCommand
                                    fillMode="flat"
                                    rounded="medium"
                                    [disabled]="stateService.state.series.length < 2"
                                ></button>
                            </ng-template>
                        </kendo-grid-command-column>
                    </kendo-grid>
                </fieldset>
                <fieldset
                    class="k-form-fieldset"
                    *ngIf="stateService.state.seriesType === 'pie'"
                >
                    <legend class="k-form-legend">
                        {{ messageFor('configurationValueAxis') }}
                    </legend>
                    <kendo-dropdownlist
                        [data]="stateService.state.columns"
                        [value]="stateService.state.valueField"
                        (valueChange)="updateState(valueAxisY, $event)"
                        fillMode="outline"
                        rounded="medium"
                        size="medium"
                    >
                    </kendo-dropdownlist>
                </fieldset>
            </form>
        </kendo-expansionpanel>
    `,
                    standalone: true,
                    imports: [
                        ExpansionPanelComponent,
                        DropDownListComponent,
                        NgIf,
                        GridComponent,
                        ReactiveEditingDirective,
                        DataBindingDirective,
                        ToolbarTemplateDirective,
                        ButtonComponent,
                        RowReorderColumnComponent,
                        ColumnComponent,
                        CommandColumnComponent,
                        CellTemplateDirective,
                        GridToolbarFocusableDirective,
                        RemoveCommandDirective
                    ]
                }]
        }], ctorParameters: function () { return [{ type: StateService }, { type: i2.FormBuilder }, { type: i0.ChangeDetectorRef }, { type: i0.Renderer2 }, { type: ChartWizardLocalizationService }]; }, propDecorators: { grid: [{
                type: ViewChild,
                args: [GridComponent]
            }] } });

/**
 * @hidden
 */
class ChartWizardSeriesTypeButtonComponent {
    stateService;
    title;
    chartTypeIcon;
    stack = false;
    seriesType;
    constructor(stateService) {
        this.stateService = stateService;
    }
    onSelect() {
        this.stateService.seriesType = this.seriesType;
        if (this.stateService.data.length > 0) {
            this.stateService.state = mergeStates(this.stateService.state, createState(this.stateService.data, this.stateService.seriesType));
            this.stateService.currentSeries = {};
            if (this.stack) {
                this.stateService.state = updateState(this.stateService.state, ActionTypes.stacked, this.stack);
            }
        }
        this.stateService.dataTab.detectChanges();
    }
    isSelected() {
        return (this.stateService.state.seriesType === this.seriesType &&
            this.stateService.state.series[0]?.stack === this.stack);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardSeriesTypeButtonComponent, deps: [{ token: StateService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ChartWizardSeriesTypeButtonComponent, isStandalone: true, selector: "kendo-chartwizard-series-type-button", inputs: { title: "title", chartTypeIcon: "chartTypeIcon", stack: "stack", seriesType: "seriesType" }, ngImport: i0, template: `
        <div class="k-icon-text-wrapper" [class.k-selected]="isSelected()" (click)="onSelect()">
            <div class="k-icon-background-area">
                <kendo-svgicon [icon]="chartTypeIcon" size="xlarge" themeColor="primary"> </kendo-svgicon>
            </div>
            {{ title }}
        </div>
    `, isInline: true, dependencies: [{ kind: "component", type: SVGIconComponent, selector: "kendo-svg-icon, kendo-svgicon", inputs: ["icon"], exportAs: ["kendoSVGIcon"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardSeriesTypeButtonComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-chartwizard-series-type-button',
                    template: `
        <div class="k-icon-text-wrapper" [class.k-selected]="isSelected()" (click)="onSelect()">
            <div class="k-icon-background-area">
                <kendo-svgicon [icon]="chartTypeIcon" size="xlarge" themeColor="primary"> </kendo-svgicon>
            </div>
            {{ title }}
        </div>
    `,
                    standalone: true,
                    imports: [SVGIconComponent]
                }]
        }], ctorParameters: function () { return [{ type: StateService }]; }, propDecorators: { title: [{
                type: Input
            }], chartTypeIcon: [{
                type: Input
            }], stack: [{
                type: Input
            }], seriesType: [{
                type: Input
            }] } });

/**
 * @hidden
 */
class ChartWizardPropertyPaneChartTabComponent {
    stateService;
    cdr;
    localization;
    exportIcon = exportIcon;
    chartBarClusteredIcon = chartBarClusteredIcon;
    chartBarStackedIcon = chartBarStackedIcon;
    chartBarStacked100Icon = chartBarStacked100Icon;
    chartPieIcon = chartPieIcon;
    chartColumnClusteredIcon = chartColumnClusteredIcon;
    chartColumnStackedIcon = chartColumnStackedIcon;
    chartColumnStacked100Icon = chartColumnStacked100Icon;
    chartLineIcon = chartLineIcon;
    chartLineStackedIcon = chartLineStackedIcon;
    chartLineStacked100Icon = chartLineStacked100Icon;
    chartScatterIcon = chartScatterIcon;
    constructor(stateService, cdr, localization) {
        this.stateService = stateService;
        this.cdr = cdr;
        this.localization = localization;
    }
    ngAfterViewChecked() {
        this.localization.changes.subscribe(() => {
            this.detectChanges();
        });
    }
    ngOnDestroy() {
        this.localization.changes.unsubscribe();
    }
    detectChanges() {
        this.cdr.detectChanges();
    }
    messageFor(key) {
        return this.localization.get(key);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardPropertyPaneChartTabComponent, deps: [{ token: StateService }, { token: i0.ChangeDetectorRef }, { token: ChartWizardLocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ChartWizardPropertyPaneChartTabComponent, isStandalone: true, selector: "kendo-chartwizard-property-pane-chart-tab", ngImport: i0, template: `
        <kendo-expansionpanel [title]="messageFor('barChart')" [expanded]="true">
            <div class="k-chart-types-wrapper">
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('barChartBar')"
                    [chartTypeIcon]="chartBarClusteredIcon"
                    seriesType="bar"
                    [stack]="false"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('barChartStackedBar')"
                    [chartTypeIcon]="chartBarStackedIcon"
                    seriesType="bar"
                    [stack]="true"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('barChart100StackedBar')"
                    [chartTypeIcon]="chartBarStacked100Icon"
                    seriesType="bar"
                    [stack]="{ type: '100%' }"
                >
                </kendo-chartwizard-series-type-button>
            </div>
        </kendo-expansionpanel>
        <kendo-expansionpanel [title]="messageFor('pieChart')" [expanded]="true">
            <div class="k-chart-types-wrapper">
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('pieChartPie')"
                    [chartTypeIcon]="chartPieIcon"
                    seriesType="pie"
                    [stack]="undefined"
                >
                </kendo-chartwizard-series-type-button>
            </div>
        </kendo-expansionpanel>
        <kendo-expansionpanel [title]="messageFor('columnChart')" [expanded]="true">
            <div class="k-chart-types-wrapper">
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('columnChartColumn')"
                    [chartTypeIcon]="chartColumnClusteredIcon"
                    seriesType="column"
                    [stack]="false"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('columnChartStackedColumn')"
                    [chartTypeIcon]="chartColumnStackedIcon"
                    seriesType="column"
                    [stack]="true"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('columnChart100StackedColumn')"
                    [chartTypeIcon]="chartColumnStacked100Icon"
                    seriesType="column"
                    [stack]="{ type: '100%' }"
                >
                </kendo-chartwizard-series-type-button>
            </div>
        </kendo-expansionpanel>
        <kendo-expansionpanel [title]="messageFor('lineChart')" [expanded]="true">
            <div class="k-chart-types-wrapper">
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('lineChartLine')"
                    [chartTypeIcon]="chartLineIcon"
                    seriesType="line"
                    [stack]="false"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('lineChartStackedLine')"
                    [chartTypeIcon]="chartLineStackedIcon"
                    seriesType="line"
                    [stack]="true"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('lineChart100StackedLine')"
                    [chartTypeIcon]="chartLineStacked100Icon"
                    seriesType="line"
                    [stack]="{ type: '100%' }"
                >
                </kendo-chartwizard-series-type-button>
            </div>
        </kendo-expansionpanel>
        <kendo-expansionpanel [title]="messageFor('scatterChart')" [expanded]="true">
            <div class="k-chart-types-wrapper">
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('scatterChartScatter')"
                    [chartTypeIcon]="chartScatterIcon"
                    seriesType="scatter"
                    [stack]="false"
                >
                </kendo-chartwizard-series-type-button>
            </div>
        </kendo-expansionpanel>
    `, isInline: true, dependencies: [{ kind: "component", type: ExpansionPanelComponent, selector: "kendo-expansionpanel", inputs: ["title", "subtitle", "disabled", "expanded", "svgExpandIcon", "svgCollapseIcon", "expandIcon", "collapseIcon", "animation"], outputs: ["expandedChange", "action", "expand", "collapse"], exportAs: ["kendoExpansionPanel"] }, { kind: "component", type: ChartWizardSeriesTypeButtonComponent, selector: "kendo-chartwizard-series-type-button", inputs: ["title", "chartTypeIcon", "stack", "seriesType"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardPropertyPaneChartTabComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-chartwizard-property-pane-chart-tab',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    template: `
        <kendo-expansionpanel [title]="messageFor('barChart')" [expanded]="true">
            <div class="k-chart-types-wrapper">
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('barChartBar')"
                    [chartTypeIcon]="chartBarClusteredIcon"
                    seriesType="bar"
                    [stack]="false"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('barChartStackedBar')"
                    [chartTypeIcon]="chartBarStackedIcon"
                    seriesType="bar"
                    [stack]="true"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('barChart100StackedBar')"
                    [chartTypeIcon]="chartBarStacked100Icon"
                    seriesType="bar"
                    [stack]="{ type: '100%' }"
                >
                </kendo-chartwizard-series-type-button>
            </div>
        </kendo-expansionpanel>
        <kendo-expansionpanel [title]="messageFor('pieChart')" [expanded]="true">
            <div class="k-chart-types-wrapper">
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('pieChartPie')"
                    [chartTypeIcon]="chartPieIcon"
                    seriesType="pie"
                    [stack]="undefined"
                >
                </kendo-chartwizard-series-type-button>
            </div>
        </kendo-expansionpanel>
        <kendo-expansionpanel [title]="messageFor('columnChart')" [expanded]="true">
            <div class="k-chart-types-wrapper">
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('columnChartColumn')"
                    [chartTypeIcon]="chartColumnClusteredIcon"
                    seriesType="column"
                    [stack]="false"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('columnChartStackedColumn')"
                    [chartTypeIcon]="chartColumnStackedIcon"
                    seriesType="column"
                    [stack]="true"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('columnChart100StackedColumn')"
                    [chartTypeIcon]="chartColumnStacked100Icon"
                    seriesType="column"
                    [stack]="{ type: '100%' }"
                >
                </kendo-chartwizard-series-type-button>
            </div>
        </kendo-expansionpanel>
        <kendo-expansionpanel [title]="messageFor('lineChart')" [expanded]="true">
            <div class="k-chart-types-wrapper">
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('lineChartLine')"
                    [chartTypeIcon]="chartLineIcon"
                    seriesType="line"
                    [stack]="false"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('lineChartStackedLine')"
                    [chartTypeIcon]="chartLineStackedIcon"
                    seriesType="line"
                    [stack]="true"
                >
                </kendo-chartwizard-series-type-button>
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('lineChart100StackedLine')"
                    [chartTypeIcon]="chartLineStacked100Icon"
                    seriesType="line"
                    [stack]="{ type: '100%' }"
                >
                </kendo-chartwizard-series-type-button>
            </div>
        </kendo-expansionpanel>
        <kendo-expansionpanel [title]="messageFor('scatterChart')" [expanded]="true">
            <div class="k-chart-types-wrapper">
                <kendo-chartwizard-series-type-button
                    [title]="messageFor('scatterChartScatter')"
                    [chartTypeIcon]="chartScatterIcon"
                    seriesType="scatter"
                    [stack]="false"
                >
                </kendo-chartwizard-series-type-button>
            </div>
        </kendo-expansionpanel>
    `,
                    standalone: true,
                    imports: [ExpansionPanelComponent, ChartWizardSeriesTypeButtonComponent]
                }]
        }], ctorParameters: function () { return [{ type: StateService }, { type: i0.ChangeDetectorRef }, { type: ChartWizardLocalizationService }]; } });

/**
 * @hidden
 */
class PreventableEvent {
    prevented = false;
    /**
     * Prevents the default action for a specified event.
     * In this way, the source component suppresses
     * the built-in behavior that follows the event.
     */
    preventDefault() {
        this.prevented = true;
    }
    /**
     * Returns `true` if the event was prevented
     * by any of its subscribers.
     *
     * @returns `true` if the default action was prevented.
     * Otherwise, returns `false`.
     */
    isDefaultPrevented() {
        return this.prevented;
    }
}

/**
 * Arguments for the `export` event on the Chart Wizard.
 */
class ExportEvent extends PreventableEvent {
    /**
     * The export options on the Chart Wizard.
     */
    exportOptions;
    /**
     * The current Chart chart instance to be exported.
     */
    chart;
    /**
     * @hidden
     */
    constructor(chart, exportOptions) {
        super();
        this.chart = chart;
        this.exportOptions = exportOptions;
    }
}

/**
 * @hidden
 */
class ChartWizardPropertyPaneFormFieldComponent {
    localization;
    cdr;
    currentState;
    action;
    class;
    inputType;
    text;
    data;
    placeholder;
    colSpan = 1;
    hasLabel = true;
    isLabelInsideFormFieldWrap = false;
    value;
    disabled = false;
    valueChange = new EventEmitter();
    formField = true;
    get isColSpan2() {
        return this.colSpan === 2;
    }
    label;
    numericTextBox;
    colorPicker;
    dropDownList;
    textBox;
    comboBox;
    checkBox;
    constructor(localization, cdr) {
        this.localization = localization;
        this.cdr = cdr;
    }
    ngAfterViewChecked() {
        this.localization.changes.subscribe(() => {
            this.cdr.detectChanges();
        });
    }
    ngOnDestroy() {
        this.localization.changes.unsubscribe();
    }
    ngAfterViewInit() {
        if (this.hasLabel) {
            this.label.for =
                this.numericTextBox ||
                    this.colorPicker ||
                    this.dropDownList ||
                    this.textBox ||
                    this.comboBox ||
                    this.checkBox;
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardPropertyPaneFormFieldComponent, deps: [{ token: i1.LocalizationService }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ChartWizardPropertyPaneFormFieldComponent, isStandalone: true, selector: "kendo-chartwizard-property-pane-form-field", inputs: { currentState: "currentState", action: "action", class: "class", inputType: "inputType", text: "text", data: "data", placeholder: "placeholder", colSpan: "colSpan", hasLabel: "hasLabel", isLabelInsideFormFieldWrap: "isLabelInsideFormFieldWrap", value: "value", disabled: "disabled" }, outputs: { valueChange: "valueChange" }, host: { properties: { "class.k-form-field": "this.formField", "class.k-col-span-2": "this.isColSpan2" } }, viewQueries: [{ propertyName: "label", first: true, predicate: LabelComponent, descendants: true }, { propertyName: "numericTextBox", first: true, predicate: NumericTextBoxComponent, descendants: true }, { propertyName: "colorPicker", first: true, predicate: ColorPickerComponent, descendants: true }, { propertyName: "dropDownList", first: true, predicate: DropDownListComponent, descendants: true }, { propertyName: "textBox", first: true, predicate: TextBoxComponent, descendants: true }, { propertyName: "comboBox", first: true, predicate: ComboBoxComponent, descendants: true }, { propertyName: "checkBox", first: true, predicate: CheckBoxComponent, descendants: true }], ngImport: i0, template: `
        <kendo-label *ngIf="hasLabel && !isLabelInsideFormFieldWrap && inputType !== 'checkbox'" class="k-form-label" [text]="text"></kendo-label>
        <div class="k-form-field-wrap">
            <kendo-label
                *ngIf="hasLabel && isLabelInsideFormFieldWrap && inputType !== 'checkbox'"
                class="k-form-label"
                [text]="text"
            ></kendo-label>
            <kendo-numerictextbox
                *ngIf="inputType === 'numeric'"
                fillMode="outline"
                rounded="medium"
                [value]="value"
                (valueChange)="valueChange.emit($event)"
                [placeholder]="placeholder"
            ></kendo-numerictextbox>
            <kendo-colorpicker
                *ngIf="inputType === 'colorPicker'"
                fillMode="outline"
                rounded="medium"
                [value]="value"
                [disabled]="disabled"
                (valueChange)="valueChange.emit($event)"
            ></kendo-colorpicker>
            <kendo-dropdownlist
                *ngIf="inputType === 'dropDownList'"
                [data]="data"
                textField="text"
                valueField="value"
                [valuePrimitive]="true"
                fillMode="outline"
                rounded="medium"
                size="medium"
                [value]="value"
                (valueChange)="valueChange.emit($event)"
            ></kendo-dropdownlist>
            <kendo-combobox
                *ngIf="inputType === 'comboBox'"
                [data]="data"
                [value]="value"
                textField="text"
                valueField="value"
                [valuePrimitive]="true"
                fillMode="outline"
                rounded="medium"
                size="medium"
                [placeholder]="placeholder"
                (valueChange)="valueChange.emit($event)"
            ></kendo-combobox>
            <kendo-textbox
                *ngIf="inputType === 'text'"
                fillMode="outline"
                rounded="medium"
                [placeholder]="placeholder"
                [value]="value"
                (valueChange)="valueChange.emit($event)"
            ></kendo-textbox>
            <kendo-checkbox
                *ngIf="inputType === 'checkbox'"
                class="k-checkbox-md k-rounded-md"
                [checkedState]="value"
                (checkedStateChange)="valueChange.emit($event)"
            ></kendo-checkbox>
            <kendo-label
                *ngIf="hasLabel && isLabelInsideFormFieldWrap && inputType === 'checkbox'"
                class="k-checkbox-label"
                [text]="text"
            ></kendo-label>
        </div>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: LabelComponent, selector: "kendo-label", inputs: ["text", "for", "optional", "labelCssStyle", "labelCssClass"], exportAs: ["kendoLabel"] }, { kind: "component", type: NumericTextBoxComponent, selector: "kendo-numerictextbox", inputs: ["focusableId", "disabled", "readonly", "title", "autoCorrect", "format", "max", "min", "decimals", "placeholder", "step", "spinners", "rangeValidation", "tabindex", "tabIndex", "changeValueOnScroll", "selectOnFocus", "value", "maxlength", "size", "rounded", "fillMode", "inputAttributes"], outputs: ["valueChange", "focus", "blur", "inputFocus", "inputBlur"], exportAs: ["kendoNumericTextBox"] }, { kind: "component", type: ColorPickerComponent, selector: "kendo-colorpicker", inputs: ["views", "view", "adaptiveMode", "activeView", "readonly", "disabled", "format", "value", "popupSettings", "paletteSettings", "gradientSettings", "icon", "iconClass", "svgIcon", "adaptiveTitle", "adaptiveSubtitle", "clearButton", "tabindex", "preview", "actionsLayout", "size", "rounded", "fillMode"], outputs: ["valueChange", "open", "close", "focus", "blur", "cancel", "activeColorClick", "clearButtonClick", "activeViewChange"], exportAs: ["kendoColorPicker"] }, { kind: "component", type: DropDownListComponent, selector: "kendo-dropdownlist", inputs: ["customIconClass", "showStickyHeader", "icon", "svgIcon", "loading", "data", "value", "textField", "valueField", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "defaultItem", "disabled", "itemDisabled", "readonly", "filterable", "virtual", "ignoreCase", "delay", "valuePrimitive", "tabindex", "tabIndex", "size", "rounded", "fillMode", "leftRightArrowsNavigation", "id"], outputs: ["valueChange", "filterChange", "selectionChange", "open", "opened", "close", "closed", "focus", "blur"], exportAs: ["kendoDropDownList"] }, { kind: "component", type: ComboBoxComponent, selector: "kendo-combobox", inputs: ["icon", "svgIcon", "inputAttributes", "showStickyHeader", "focusableId", "allowCustom", "data", "value", "textField", "valueField", "valuePrimitive", "valueNormalizer", "placeholder", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "loading", "suggest", "clearButton", "disabled", "itemDisabled", "readonly", "tabindex", "tabIndex", "filterable", "virtual", "size", "rounded", "fillMode"], outputs: ["valueChange", "selectionChange", "filterChange", "open", "opened", "close", "closed", "focus", "blur", "inputFocus", "inputBlur", "escape"], exportAs: ["kendoComboBox"] }, { kind: "component", type: TextBoxComponent, selector: "kendo-textbox", inputs: ["focusableId", "title", "type", "disabled", "readonly", "tabindex", "value", "selectOnFocus", "showSuccessIcon", "showErrorIcon", "clearButton", "successIcon", "successSvgIcon", "errorIcon", "errorSvgIcon", "clearButtonIcon", "clearButtonSvgIcon", "size", "rounded", "fillMode", "tabIndex", "placeholder", "maxlength", "inputAttributes"], outputs: ["valueChange", "inputFocus", "inputBlur", "focus", "blur"], exportAs: ["kendoTextBox"] }, { kind: "component", type: CheckBoxComponent, selector: "kendo-checkbox", inputs: ["checkedState", "rounded"], outputs: ["checkedStateChange"], exportAs: ["kendoCheckBox"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardPropertyPaneFormFieldComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-chartwizard-property-pane-form-field',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    template: `
        <kendo-label *ngIf="hasLabel && !isLabelInsideFormFieldWrap && inputType !== 'checkbox'" class="k-form-label" [text]="text"></kendo-label>
        <div class="k-form-field-wrap">
            <kendo-label
                *ngIf="hasLabel && isLabelInsideFormFieldWrap && inputType !== 'checkbox'"
                class="k-form-label"
                [text]="text"
            ></kendo-label>
            <kendo-numerictextbox
                *ngIf="inputType === 'numeric'"
                fillMode="outline"
                rounded="medium"
                [value]="value"
                (valueChange)="valueChange.emit($event)"
                [placeholder]="placeholder"
            ></kendo-numerictextbox>
            <kendo-colorpicker
                *ngIf="inputType === 'colorPicker'"
                fillMode="outline"
                rounded="medium"
                [value]="value"
                [disabled]="disabled"
                (valueChange)="valueChange.emit($event)"
            ></kendo-colorpicker>
            <kendo-dropdownlist
                *ngIf="inputType === 'dropDownList'"
                [data]="data"
                textField="text"
                valueField="value"
                [valuePrimitive]="true"
                fillMode="outline"
                rounded="medium"
                size="medium"
                [value]="value"
                (valueChange)="valueChange.emit($event)"
            ></kendo-dropdownlist>
            <kendo-combobox
                *ngIf="inputType === 'comboBox'"
                [data]="data"
                [value]="value"
                textField="text"
                valueField="value"
                [valuePrimitive]="true"
                fillMode="outline"
                rounded="medium"
                size="medium"
                [placeholder]="placeholder"
                (valueChange)="valueChange.emit($event)"
            ></kendo-combobox>
            <kendo-textbox
                *ngIf="inputType === 'text'"
                fillMode="outline"
                rounded="medium"
                [placeholder]="placeholder"
                [value]="value"
                (valueChange)="valueChange.emit($event)"
            ></kendo-textbox>
            <kendo-checkbox
                *ngIf="inputType === 'checkbox'"
                class="k-checkbox-md k-rounded-md"
                [checkedState]="value"
                (checkedStateChange)="valueChange.emit($event)"
            ></kendo-checkbox>
            <kendo-label
                *ngIf="hasLabel && isLabelInsideFormFieldWrap && inputType === 'checkbox'"
                class="k-checkbox-label"
                [text]="text"
            ></kendo-label>
        </div>
    `,
                    standalone: true,
                    imports: [
                        NgIf,
                        LabelComponent,
                        NumericTextBoxComponent,
                        ColorPickerComponent,
                        DropDownListComponent,
                        ComboBoxComponent,
                        TextBoxComponent,
                        CheckBoxComponent
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { currentState: [{
                type: Input
            }], action: [{
                type: Input
            }], class: [{
                type: Input
            }], inputType: [{
                type: Input
            }], text: [{
                type: Input
            }], data: [{
                type: Input
            }], placeholder: [{
                type: Input
            }], colSpan: [{
                type: Input
            }], hasLabel: [{
                type: Input
            }], isLabelInsideFormFieldWrap: [{
                type: Input
            }], value: [{
                type: Input
            }], disabled: [{
                type: Input
            }], valueChange: [{
                type: Output
            }], formField: [{
                type: HostBinding,
                args: ['class.k-form-field']
            }], isColSpan2: [{
                type: HostBinding,
                args: ['class.k-col-span-2']
            }], label: [{
                type: ViewChild,
                args: [LabelComponent]
            }], numericTextBox: [{
                type: ViewChild,
                args: [NumericTextBoxComponent]
            }], colorPicker: [{
                type: ViewChild,
                args: [ColorPickerComponent]
            }], dropDownList: [{
                type: ViewChild,
                args: [DropDownListComponent]
            }], textBox: [{
                type: ViewChild,
                args: [TextBoxComponent]
            }], comboBox: [{
                type: ViewChild,
                args: [ComboBoxComponent]
            }], checkBox: [{
                type: ViewChild,
                args: [CheckBoxComponent]
            }] } });

/**
 * @hidden
 */
class ChartWizardPropertyPaneFormatTabComponent {
    stateService;
    localization;
    cdr;
    chartTitles;
    areaMarginLeft = ActionTypes.areaMarginLeft;
    areaMarginRight = ActionTypes.areaMarginRight;
    areaMarginTop = ActionTypes.areaMarginTop;
    areaMarginBottom = ActionTypes.areaMarginBottom;
    areaBackground = ActionTypes.areaBackground;
    legendVisible = ActionTypes.legendVisible;
    legendFontName = ActionTypes.legendFontName;
    legendFontSize = ActionTypes.legendFontSize;
    legendColor = ActionTypes.legendColor;
    legendPosition = ActionTypes.legendPosition;
    categoryAxisTitleText = ActionTypes.categoryAxisTitleText;
    categoryAxisTitleFontName = ActionTypes.categoryAxisTitleFontName;
    categoryAxisTitleFontSize = ActionTypes.categoryAxisTitleFontSize;
    categoryAxisTitleColor = ActionTypes.categoryAxisTitleColor;
    categoryAxisLabelsFontName = ActionTypes.categoryAxisLabelsFontName;
    categoryAxisLabelsFontSize = ActionTypes.categoryAxisLabelsFontSize;
    categoryAxisLabelsColor = ActionTypes.categoryAxisLabelsColor;
    categoryAxisLabelsRotation = ActionTypes.categoryAxisLabelsRotation;
    categoryAxisReverseOrder = ActionTypes.categoryAxisReverseOrder;
    valueAxisTitleText = ActionTypes.valueAxisTitleText;
    valueAxisTitleFontName = ActionTypes.valueAxisTitleFontName;
    valueAxisTitleFontSize = ActionTypes.valueAxisTitleFontSize;
    valueAxisTitleColor = ActionTypes.valueAxisTitleColor;
    valueAxisLabelsFontName = ActionTypes.valueAxisLabelsFontName;
    valueAxisLabelsFormat = ActionTypes.valueAxisLabelsFormat;
    valueAxisLabelsFontSize = ActionTypes.valueAxisLabelsFontSize;
    valueAxisLabelsColor = ActionTypes.valueAxisLabelsColor;
    valueAxisLabelsRotation = ActionTypes.valueAxisLabelsRotation;
    parseFont = parseFont;
    defaultAllSeriesItem = defaultAllSeriesItem;
    fontNames = fontNames;
    fontSizes = fontSizes;
    labelFormats;
    legendPositions;
    labelsCategoryAxisRotation;
    labelsValueAxisRotation;
    get chartTitleTypeText() {
        return this.stateService.currentTitle === 'Chart Title'
            ? this.stateService.state.title?.text
            : this.stateService.state.subtitle?.text;
    }
    get chartTitleTypeFont() {
        return this.stateService.currentTitle === 'Chart Title'
            ? parseFont(this.stateService.state.title?.font).name
            : parseFont(this.stateService.state.subtitle?.font).name;
    }
    get chartTitleTypeFontSize() {
        return this.stateService.currentTitle === 'Chart Title'
            ? parseFont(this.stateService.state.title?.font).size
            : parseFont(this.stateService.state.subtitle?.font).size;
    }
    get chartTitleTypeColor() {
        return this.stateService.currentTitle === 'Chart Title'
            ? this.stateService.state.title?.color
            : this.stateService.state.subtitle?.color;
    }
    get chartTitleTypeAction() {
        return this.stateService.currentTitle === 'Chart Title' ? ActionTypes.titleText : ActionTypes.subtitleText;
    }
    get chartTitleTypeFontAction() {
        return this.stateService.currentTitle === 'Chart Title' ? ActionTypes.titleFontName : ActionTypes.subtitleFontName;
    }
    get chartTitleTypeColorAction() {
        return this.stateService.currentTitle === 'Chart Title' ? ActionTypes.titleColor : ActionTypes.subtitleColor;
    }
    get chartTitleTypeFontSizeAction() {
        return this.stateService.currentTitle === 'Chart Title' ? ActionTypes.titleFontSize : ActionTypes.subtitleFontSize;
    }
    get seriesData() {
        return [
            { text: this.messageFor('formatSeriesAllSeries'), name: 'All Series' },
            ...this.stateService.state.series.map(item => ({ text: item.name, ...item }))
        ];
    }
    get showLabels() {
        return this.stateService.currentSeries.name !== defaultAllSeriesItem.name ? this.stateService.state.series.find(s => s.name === this.stateService.currentSeries.name)?.labels?.visible : this.stateService.state.series.every(s => s.labels?.visible);
    }
    get labelFormatValue() {
        return labelFormats.find(f => f.value === this.stateService.state.valueAxis[0]?.labels?.format)?.value || defaultFormat.value;
    }
    constructor(stateService, localization, cdr) {
        this.stateService = stateService;
        this.localization = localization;
        this.cdr = cdr;
        this.labelFormats = [
            { value: '', text: this.messageFor('formatValueAxisLabelsFormatText') },
            { value: 'n0', text: this.messageFor('formatValueAxisLabelsFormatNumber') },
            { value: 'c0', text: this.messageFor('formatValueAxisLabelsFormatCurrency') },
            { value: 'p0', text: this.messageFor('formatValueAxisLabelsFormatPercent') }
        ];
        this.legendPositions = [
            { text: this.messageFor('formatLegendPositionTop'), value: 'top' },
            { text: this.messageFor('formatLegendPositionBottom'), value: 'bottom' },
            { text: this.messageFor('formatLegendPositionLeft'), value: 'left' },
            { text: this.messageFor('formatLegendPositionRight'), value: 'right' }
        ];
        this.labelsCategoryAxisRotation = [
            { text: this.messageFor('formatCategoryAxisLabelsRotationAuto'), value: 'auto' },
            { text: '0°', value: 0 },
            { text: '45°', value: 45 },
            { text: '90°', value: 90 },
            { text: '135°', value: 135 },
            { text: '180°', value: 180 }
        ];
        this.labelsValueAxisRotation = [
            { text: this.messageFor('formatValueAxisLabelsRotationAuto'), value: 'auto' },
            { text: '0°', value: 0 },
            { text: '45°', value: 45 },
            { text: '90°', value: 90 },
            { text: '135°', value: 135 },
            { text: '180°', value: 180 }
        ];
        this.chartTitles = [
            { text: this.messageFor('formatTitleChartTitle'), value: 'Chart Title' },
            { text: this.messageFor('formatTitleChartSubtitle'), value: 'Chart Subtitle' },
        ];
    }
    ngAfterViewChecked() {
        this.localization.changes.subscribe(() => {
            this.cdr.detectChanges();
        });
    }
    ngOnDestroy() {
        this.localization.changes.unsubscribe();
    }
    updateState(action, value) {
        if (action === ActionTypes.seriesLabel && this.stateService.currentSeries.name === defaultAllSeriesItem.name) {
            this.stateService.state = updateState(this.stateService.state, action, { name: '', all: true, visible: value.labels.visible });
            return;
        }
        this.stateService.state = updateState(this.stateService.state, action, value);
    }
    changeCurrentTitle(value) {
        this.stateService.currentTitle = value;
    }
    toggleSeriesLabels(value) {
        this.updateCurrentSeries(this.stateService.currentSeries);
        this.stateService.currentSeries.labels = { visible: value };
        this.updateState(ActionTypes.seriesLabel, this.stateService.currentSeries);
    }
    updateCurrentSeries(value) {
        if (value.name === defaultAllSeriesItem.name) {
            this.stateService.currentSeries = defaultAllSeriesItem;
        }
        else {
            this.stateService.currentSeries = this.stateService.state.series.find((series) => series.name === value.name);
        }
    }
    updateSeriesColor(value) {
        this.updateCurrentSeries(this.stateService.currentSeries);
        this.stateService.currentSeries.color = value;
        this.updateState(ActionTypes.seriesColor, this.stateService.currentSeries);
    }
    messageFor(key) {
        return this.localization.get(key);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardPropertyPaneFormatTabComponent, deps: [{ token: StateService }, { token: ChartWizardLocalizationService }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ChartWizardPropertyPaneFormatTabComponent, isStandalone: true, selector: "kendo-chartwizard-property-pane-format-tab", ngImport: i0, template: `
        <section>
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="messageFor('formatChartArea')"
                [expanded]="true"
                [attr.dir]="stateService.direction"
            >
                <form class="k-form k-form-md">
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatChartAreaMargins') }}</legend>
                        <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatChartAreaMarginsLeft')"
                                inputType="numeric"
                                [placeholder]="messageFor('formatChartAreaMarginsAuto')"
                                [value]="$any(stateService.state.area.margin).left"
                                (valueChange)="updateState(areaMarginLeft, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatChartAreaMarginsRight')"
                                inputType="numeric"
                                [placeholder]="messageFor('formatChartAreaMarginsAuto')"
                                [value]="$any(stateService.state.area.margin).right"
                                (valueChange)="updateState(areaMarginRight, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatChartAreaMarginsTop')"
                                inputType="numeric"
                                [placeholder]="messageFor('formatChartAreaMarginsAuto')"
                                [value]="$any(stateService.state.area.margin).top"
                                (valueChange)="updateState(areaMarginTop, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatChartAreaMarginsBottom')"
                                inputType="numeric"
                                [placeholder]="messageFor('formatChartAreaMarginsAuto')"
                                [value]="$any(stateService.state.area.margin).bottom"
                                (valueChange)="updateState(areaMarginBottom, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                        </div>
                    </fieldset>
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatChartAreaBackground') }}</legend>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatChartAreaBackgroundColor')"
                            inputType="colorPicker"
                            [value]="stateService.state.area?.background"
                            (valueChange)="updateState(areaBackground, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                    </fieldset>
                </form>
            </kendo-expansionpanel>
        </section>
        <section>
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="messageFor('formatTitle')"
                [expanded]="true"
            >
                <form class="k-form k-form-md">
                    <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatTitleApplyTo')"
                            inputType="dropDownList"
                            [data]="chartTitles"
                            [colSpan]="2"
                            [value]="stateService.currentTitle"
                            (valueChange)="changeCurrentTitle($event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatTitleLabel')"
                            inputType="text"
                            [colSpan]="2"
                            [value]="chartTitleTypeText"
                            (valueChange)="updateState(chartTitleTypeAction, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatTitleFont')"
                            inputType="comboBox"
                            [data]="fontNames"
                            [colSpan]="2"
                            [value]="chartTitleTypeFont"
                            [placeholder]="messageFor('formatTitleFontPlaceholder')"
                            (valueChange)="updateState(chartTitleTypeFontAction, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatTitleSize')"
                            inputType="comboBox"
                            [placeholder]="messageFor('formatTitleSizePlaceholder')"
                            [data]="fontSizes"
                            [value]="chartTitleTypeFontSize"
                            (valueChange)="updateState(chartTitleTypeFontSizeAction, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatTitleColor')"
                            inputType="colorPicker"
                            [value]="chartTitleTypeColor"
                            (valueChange)="updateState(chartTitleTypeColorAction, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                    </div>
                </form>
            </kendo-expansionpanel>
        </section>
        <section>
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="messageFor('formatLegend')"
                [expanded]="true"
            >
                <form class="k-form k-form-md">
                    <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                        <kendo-label [for]="toggleLegend" [text]="messageFor('formatLegendShowLegend')"></kendo-label>
                        <kendo-switch
                            #toggleLegend
                            onLabel="On"
                            offLabel="Off"
                            thumbRounded="full"
                            size="medium"
                            [checked]="stateService.state.legend?.visible"
                            (valueChange)="updateState(legendVisible, $event)"
                        ></kendo-switch>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatLegendFont')"
                            inputType="comboBox"
                            [data]="fontNames"
                            [colSpan]="2"
                            [placeholder]="messageFor('formatLegendFontPlaceholder')"
                            [value]="parseFont(stateService.state.legend?.labels?.font).name"
                            (valueChange)="updateState(legendFontName, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatLegendSize')"
                            inputType="comboBox"
                            [data]="fontSizes"
                            [placeholder]="messageFor('formatLegendSizePlaceholder')"
                            [value]="parseFont(stateService.state.legend?.labels?.font).size"
                            (valueChange)="updateState(legendFontSize, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatLegendColor')"
                            inputType="colorPicker"
                            [value]="stateService.state.legend?.labels?.color"
                            (valueChange)="updateState(legendColor, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatLegendPosition')"
                            inputType="dropDownList"
                            [colSpan]="2"
                            [data]="legendPositions"
                            [value]="stateService.state.legend?.position"
                            (valueChange)="updateState(legendPosition, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                    </div>
                </form>
            </kendo-expansionpanel>
        </section>
        <section>
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="messageFor('formatSeries')"
                [expanded]="true"
            >
                <form class="k-form k-form-md">
                    <div class="k-form-field">
                        <kendo-label [for]="seriesDropDown" class="k-form-label" [text]="messageFor('formatSeriesApplyTo')"></kendo-label>
                        <div class="k-form-field-wrap">
                            <kendo-dropdownlist
                                #seriesDropDown
                                [data]="seriesData"
                                textField="text"
                                valueField="name"
                                fillMode="outline"
                                rounded="medium"
                                size="medium"
                                [value]="stateService.currentSeries"
                                (valueChange)="updateCurrentSeries($event)"
                            ></kendo-dropdownlist>
                        </div>
                    </div>

                    <kendo-chartwizard-property-pane-form-field
                        [text]="messageFor('formatSeriesColor')"
                        [value]="stateService.currentSeries?.color"
                        inputType="colorPicker"
                        [disabled]="stateService.currentSeries.name === defaultAllSeriesItem.name"
                        (valueChange)="updateSeriesColor($event)"
                    >
                    </kendo-chartwizard-property-pane-form-field>
                    <kendo-chartwizard-property-pane-form-field
                        [text]="messageFor('formatSeriesShowLabels')"
                        [value]="showLabels"
                        [isLabelInsideFormFieldWrap]="true"
                        [colSpan]="2"
                        inputType="checkbox"
                        (valueChange)="toggleSeriesLabels($event)"
                    >
                    </kendo-chartwizard-property-pane-form-field>
                </form>
            </kendo-expansionpanel>
        </section>
        <section *ngIf="stateService.state.seriesType !== 'pie'" class="k-row-start-1 k-row-end-3 k-col-start-3">
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="stateService.state.seriesType === 'scatter' ? messageFor('formatXAxis') : messageFor('formatCategoryAxis')"
                [expanded]="true"
            >
                <form class="k-form k-form-md">
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatCategoryAxisTitle') }}</legend>
                        <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                            <kendo-chartwizard-property-pane-form-field
                                inputType="text"
                                [hasLabel]="false"
                                [colSpan]="2"
                                [placeholder]="messageFor('formatCategoryAxisTitlePlaceholder')"
                                [value]="stateService.state.categoryAxis[0]?.title?.text || null"
                                (valueChange)="updateState(categoryAxisTitleText, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisTitleFont')"
                                inputType="comboBox"
                                [data]="fontNames"
                                [colSpan]="2"
                                [placeholder]="messageFor('formatCategoryAxisTitleFontPlaceholder')"
                                [value]="parseFont(stateService.state.categoryAxis[0]?.title?.font).name"
                                (valueChange)="updateState(categoryAxisTitleFontName, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisTitleSize')"
                                inputType="comboBox"
                                [placeholder]="messageFor('formatCategoryAxisTitleSizePlaceholder')"
                                [data]="fontSizes"
                                [value]="parseFont(stateService.state.categoryAxis[0]?.title?.font).size"
                                (valueChange)="updateState(categoryAxisTitleFontSize, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisTitleColor')"
                                inputType="colorPicker"
                                [value]="stateService.state.categoryAxis[0]?.title?.color"
                                (valueChange)="updateState(categoryAxisTitleColor, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                        </div>
                    </fieldset>
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatCategoryAxisLabels') }}</legend>
                        <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisLabelsFont')"
                                inputType="comboBox"
                                [data]="fontNames"
                                [colSpan]="2"
                                [placeholder]="messageFor('formatCategoryAxisLabelsFontPlaceholder')"
                                [value]="parseFont(stateService.state.categoryAxis[0]?.labels?.font).name"
                                (valueChange)="updateState(categoryAxisLabelsFontName, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisLabelsSize')"
                                inputType="comboBox"
                                [data]="fontSizes"
                                [placeholder]="messageFor('formatCategoryAxisLabelsSizePlaceholder')"
                                [value]="parseFont(stateService.state.categoryAxis[0]?.labels?.font).size"
                                (valueChange)="updateState(categoryAxisLabelsFontSize, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisLabelsColor')"
                                inputType="colorPicker"
                                [value]="stateService.state.categoryAxis[0]?.labels?.color"
                                (valueChange)="updateState(categoryAxisLabelsColor, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisLabelsRotation')"
                                inputType="dropDownList"
                                [data]="labelsCategoryAxisRotation"
                                [value]="stateService.state.categoryAxis[0]?.labels?.rotation"
                                (valueChange)="updateState(categoryAxisLabelsRotation, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <span></span>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisLabelsReverseOrder')"
                                [isLabelInsideFormFieldWrap]="true"
                                inputType="checkbox"
                                [colSpan]="2"
                                [value]="stateService.state.categoryAxis[0]?.reverse"
                                (valueChange)="updateState(categoryAxisReverseOrder, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                        </div>
                    </fieldset>
                </form>
            </kendo-expansionpanel>
        </section>
        <section *ngIf="stateService.state.seriesType !== 'pie'" class="k-row-start-1 k-row-end-3 k-col-start-4">
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="stateService.state.seriesType === 'scatter' ? messageFor('formatYAxis') : messageFor('formatValueAxis')"
                [expanded]="true"
            >
                <form class="k-form k-form-md">
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatValueAxisTitle') }}</legend>
                        <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                            <kendo-chartwizard-property-pane-form-field
                                inputType="text"
                                [hasLabel]="false"
                                [colSpan]="2"
                                [placeholder]="messageFor('formatValueAxisTitlePlaceholder')"
                                [value]="stateService.state.valueAxis[0]?.title?.text || null"
                                (valueChange)="updateState(valueAxisTitleText, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisTitleFont')"
                                inputType="comboBox"
                                [colSpan]="2"
                                [data]="fontNames"
                                [placeholder]="messageFor('formatValueAxisTitleFontPlaceholder')"
                                [value]="parseFont(stateService.state.valueAxis[0]?.title?.font).name"
                                (valueChange)="updateState(valueAxisTitleFontName, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisTitleSize')"
                                inputType="comboBox"
                                [placeholder]="messageFor('formatValueAxisTitleSizePlaceholder')"
                                [data]="fontSizes"
                                [value]="parseFont(stateService.state.valueAxis[0]?.title?.font).size"
                                (valueChange)="updateState(valueAxisTitleFontSize, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisTitleColor')"
                                inputType="colorPicker"
                                [value]="stateService.state.valueAxis[0]?.title?.color"
                                (valueChange)="updateState(valueAxisTitleColor, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                        </div>
                    </fieldset>
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatValueAxisLabels') }}</legend>
                        <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisLabelsFormat')"
                                [colSpan]="2"
                                inputType="dropDownList"
                                [data]="labelFormats"
                                [value]="labelFormatValue"
                                (valueChange)="updateState(valueAxisLabelsFormat, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisLabelsFont')"
                                inputType="comboBox"
                                [data]="fontNames"
                                [colSpan]="2"
                                [placeholder]="messageFor('formatValueAxisLabelsFontPlaceholder')"
                                [value]="parseFont(stateService.state.valueAxis[0]?.labels?.font).name"
                                (valueChange)="updateState(valueAxisLabelsFontName, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisLabelsSize')"
                                inputType="comboBox"
                                [data]="fontSizes"
                                [placeholder]="messageFor('formatValueAxisLabelsSizePlaceholder')"
                                [value]="parseFont(stateService.state.valueAxis[0]?.labels?.font).size"
                                (valueChange)="updateState(valueAxisLabelsFontSize, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisLabelsColor')"
                                inputType="colorPicker"
                                [value]="stateService.state.valueAxis[0]?.labels?.color"
                                (valueChange)="updateState(valueAxisLabelsColor, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisLabelsRotation')"
                                inputType="dropDownList"
                                [data]="labelsValueAxisRotation"
                                [value]="stateService.state.valueAxis[0]?.labels?.rotation"
                                (valueChange)="updateState(valueAxisLabelsRotation, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                        </div>
                    </fieldset>
                </form>
            </kendo-expansionpanel>
        </section>
    `, isInline: true, dependencies: [{ kind: "component", type: ExpansionPanelComponent, selector: "kendo-expansionpanel", inputs: ["title", "subtitle", "disabled", "expanded", "svgExpandIcon", "svgCollapseIcon", "expandIcon", "collapseIcon", "animation"], outputs: ["expandedChange", "action", "expand", "collapse"], exportAs: ["kendoExpansionPanel"] }, { kind: "component", type: ChartWizardPropertyPaneFormFieldComponent, selector: "kendo-chartwizard-property-pane-form-field", inputs: ["currentState", "action", "class", "inputType", "text", "data", "placeholder", "colSpan", "hasLabel", "isLabelInsideFormFieldWrap", "value", "disabled"], outputs: ["valueChange"] }, { kind: "component", type: LabelComponent, selector: "kendo-label", inputs: ["text", "for", "optional", "labelCssStyle", "labelCssClass"], exportAs: ["kendoLabel"] }, { kind: "component", type: SwitchComponent, selector: "kendo-switch", inputs: ["focusableId", "onLabel", "offLabel", "checked", "disabled", "readonly", "tabindex", "size", "thumbRounded", "trackRounded", "tabIndex"], outputs: ["focus", "blur", "valueChange"], exportAs: ["kendoSwitch"] }, { kind: "component", type: DropDownListComponent, selector: "kendo-dropdownlist", inputs: ["customIconClass", "showStickyHeader", "icon", "svgIcon", "loading", "data", "value", "textField", "valueField", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "defaultItem", "disabled", "itemDisabled", "readonly", "filterable", "virtual", "ignoreCase", "delay", "valuePrimitive", "tabindex", "tabIndex", "size", "rounded", "fillMode", "leftRightArrowsNavigation", "id"], outputs: ["valueChange", "filterChange", "selectionChange", "open", "opened", "close", "closed", "focus", "blur"], exportAs: ["kendoDropDownList"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardPropertyPaneFormatTabComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-chartwizard-property-pane-format-tab',
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    template: `
        <section>
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="messageFor('formatChartArea')"
                [expanded]="true"
                [attr.dir]="stateService.direction"
            >
                <form class="k-form k-form-md">
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatChartAreaMargins') }}</legend>
                        <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatChartAreaMarginsLeft')"
                                inputType="numeric"
                                [placeholder]="messageFor('formatChartAreaMarginsAuto')"
                                [value]="$any(stateService.state.area.margin).left"
                                (valueChange)="updateState(areaMarginLeft, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatChartAreaMarginsRight')"
                                inputType="numeric"
                                [placeholder]="messageFor('formatChartAreaMarginsAuto')"
                                [value]="$any(stateService.state.area.margin).right"
                                (valueChange)="updateState(areaMarginRight, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatChartAreaMarginsTop')"
                                inputType="numeric"
                                [placeholder]="messageFor('formatChartAreaMarginsAuto')"
                                [value]="$any(stateService.state.area.margin).top"
                                (valueChange)="updateState(areaMarginTop, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatChartAreaMarginsBottom')"
                                inputType="numeric"
                                [placeholder]="messageFor('formatChartAreaMarginsAuto')"
                                [value]="$any(stateService.state.area.margin).bottom"
                                (valueChange)="updateState(areaMarginBottom, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                        </div>
                    </fieldset>
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatChartAreaBackground') }}</legend>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatChartAreaBackgroundColor')"
                            inputType="colorPicker"
                            [value]="stateService.state.area?.background"
                            (valueChange)="updateState(areaBackground, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                    </fieldset>
                </form>
            </kendo-expansionpanel>
        </section>
        <section>
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="messageFor('formatTitle')"
                [expanded]="true"
            >
                <form class="k-form k-form-md">
                    <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatTitleApplyTo')"
                            inputType="dropDownList"
                            [data]="chartTitles"
                            [colSpan]="2"
                            [value]="stateService.currentTitle"
                            (valueChange)="changeCurrentTitle($event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatTitleLabel')"
                            inputType="text"
                            [colSpan]="2"
                            [value]="chartTitleTypeText"
                            (valueChange)="updateState(chartTitleTypeAction, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatTitleFont')"
                            inputType="comboBox"
                            [data]="fontNames"
                            [colSpan]="2"
                            [value]="chartTitleTypeFont"
                            [placeholder]="messageFor('formatTitleFontPlaceholder')"
                            (valueChange)="updateState(chartTitleTypeFontAction, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatTitleSize')"
                            inputType="comboBox"
                            [placeholder]="messageFor('formatTitleSizePlaceholder')"
                            [data]="fontSizes"
                            [value]="chartTitleTypeFontSize"
                            (valueChange)="updateState(chartTitleTypeFontSizeAction, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatTitleColor')"
                            inputType="colorPicker"
                            [value]="chartTitleTypeColor"
                            (valueChange)="updateState(chartTitleTypeColorAction, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                    </div>
                </form>
            </kendo-expansionpanel>
        </section>
        <section>
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="messageFor('formatLegend')"
                [expanded]="true"
            >
                <form class="k-form k-form-md">
                    <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                        <kendo-label [for]="toggleLegend" [text]="messageFor('formatLegendShowLegend')"></kendo-label>
                        <kendo-switch
                            #toggleLegend
                            onLabel="On"
                            offLabel="Off"
                            thumbRounded="full"
                            size="medium"
                            [checked]="stateService.state.legend?.visible"
                            (valueChange)="updateState(legendVisible, $event)"
                        ></kendo-switch>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatLegendFont')"
                            inputType="comboBox"
                            [data]="fontNames"
                            [colSpan]="2"
                            [placeholder]="messageFor('formatLegendFontPlaceholder')"
                            [value]="parseFont(stateService.state.legend?.labels?.font).name"
                            (valueChange)="updateState(legendFontName, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatLegendSize')"
                            inputType="comboBox"
                            [data]="fontSizes"
                            [placeholder]="messageFor('formatLegendSizePlaceholder')"
                            [value]="parseFont(stateService.state.legend?.labels?.font).size"
                            (valueChange)="updateState(legendFontSize, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatLegendColor')"
                            inputType="colorPicker"
                            [value]="stateService.state.legend?.labels?.color"
                            (valueChange)="updateState(legendColor, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                        <kendo-chartwizard-property-pane-form-field
                            [text]="messageFor('formatLegendPosition')"
                            inputType="dropDownList"
                            [colSpan]="2"
                            [data]="legendPositions"
                            [value]="stateService.state.legend?.position"
                            (valueChange)="updateState(legendPosition, $event)"
                        >
                        </kendo-chartwizard-property-pane-form-field>
                    </div>
                </form>
            </kendo-expansionpanel>
        </section>
        <section>
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="messageFor('formatSeries')"
                [expanded]="true"
            >
                <form class="k-form k-form-md">
                    <div class="k-form-field">
                        <kendo-label [for]="seriesDropDown" class="k-form-label" [text]="messageFor('formatSeriesApplyTo')"></kendo-label>
                        <div class="k-form-field-wrap">
                            <kendo-dropdownlist
                                #seriesDropDown
                                [data]="seriesData"
                                textField="text"
                                valueField="name"
                                fillMode="outline"
                                rounded="medium"
                                size="medium"
                                [value]="stateService.currentSeries"
                                (valueChange)="updateCurrentSeries($event)"
                            ></kendo-dropdownlist>
                        </div>
                    </div>

                    <kendo-chartwizard-property-pane-form-field
                        [text]="messageFor('formatSeriesColor')"
                        [value]="stateService.currentSeries?.color"
                        inputType="colorPicker"
                        [disabled]="stateService.currentSeries.name === defaultAllSeriesItem.name"
                        (valueChange)="updateSeriesColor($event)"
                    >
                    </kendo-chartwizard-property-pane-form-field>
                    <kendo-chartwizard-property-pane-form-field
                        [text]="messageFor('formatSeriesShowLabels')"
                        [value]="showLabels"
                        [isLabelInsideFormFieldWrap]="true"
                        [colSpan]="2"
                        inputType="checkbox"
                        (valueChange)="toggleSeriesLabels($event)"
                    >
                    </kendo-chartwizard-property-pane-form-field>
                </form>
            </kendo-expansionpanel>
        </section>
        <section *ngIf="stateService.state.seriesType !== 'pie'" class="k-row-start-1 k-row-end-3 k-col-start-3">
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="stateService.state.seriesType === 'scatter' ? messageFor('formatXAxis') : messageFor('formatCategoryAxis')"
                [expanded]="true"
            >
                <form class="k-form k-form-md">
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatCategoryAxisTitle') }}</legend>
                        <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                            <kendo-chartwizard-property-pane-form-field
                                inputType="text"
                                [hasLabel]="false"
                                [colSpan]="2"
                                [placeholder]="messageFor('formatCategoryAxisTitlePlaceholder')"
                                [value]="stateService.state.categoryAxis[0]?.title?.text || null"
                                (valueChange)="updateState(categoryAxisTitleText, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisTitleFont')"
                                inputType="comboBox"
                                [data]="fontNames"
                                [colSpan]="2"
                                [placeholder]="messageFor('formatCategoryAxisTitleFontPlaceholder')"
                                [value]="parseFont(stateService.state.categoryAxis[0]?.title?.font).name"
                                (valueChange)="updateState(categoryAxisTitleFontName, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisTitleSize')"
                                inputType="comboBox"
                                [placeholder]="messageFor('formatCategoryAxisTitleSizePlaceholder')"
                                [data]="fontSizes"
                                [value]="parseFont(stateService.state.categoryAxis[0]?.title?.font).size"
                                (valueChange)="updateState(categoryAxisTitleFontSize, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisTitleColor')"
                                inputType="colorPicker"
                                [value]="stateService.state.categoryAxis[0]?.title?.color"
                                (valueChange)="updateState(categoryAxisTitleColor, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                        </div>
                    </fieldset>
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatCategoryAxisLabels') }}</legend>
                        <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisLabelsFont')"
                                inputType="comboBox"
                                [data]="fontNames"
                                [colSpan]="2"
                                [placeholder]="messageFor('formatCategoryAxisLabelsFontPlaceholder')"
                                [value]="parseFont(stateService.state.categoryAxis[0]?.labels?.font).name"
                                (valueChange)="updateState(categoryAxisLabelsFontName, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisLabelsSize')"
                                inputType="comboBox"
                                [data]="fontSizes"
                                [placeholder]="messageFor('formatCategoryAxisLabelsSizePlaceholder')"
                                [value]="parseFont(stateService.state.categoryAxis[0]?.labels?.font).size"
                                (valueChange)="updateState(categoryAxisLabelsFontSize, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisLabelsColor')"
                                inputType="colorPicker"
                                [value]="stateService.state.categoryAxis[0]?.labels?.color"
                                (valueChange)="updateState(categoryAxisLabelsColor, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisLabelsRotation')"
                                inputType="dropDownList"
                                [data]="labelsCategoryAxisRotation"
                                [value]="stateService.state.categoryAxis[0]?.labels?.rotation"
                                (valueChange)="updateState(categoryAxisLabelsRotation, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <span></span>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatCategoryAxisLabelsReverseOrder')"
                                [isLabelInsideFormFieldWrap]="true"
                                inputType="checkbox"
                                [colSpan]="2"
                                [value]="stateService.state.categoryAxis[0]?.reverse"
                                (valueChange)="updateState(categoryAxisReverseOrder, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                        </div>
                    </fieldset>
                </form>
            </kendo-expansionpanel>
        </section>
        <section *ngIf="stateService.state.seriesType !== 'pie'" class="k-row-start-1 k-row-end-3 k-col-start-4">
            <kendo-expansionpanel
                [style.max-width.px]="576"
                [title]="stateService.state.seriesType === 'scatter' ? messageFor('formatYAxis') : messageFor('formatValueAxis')"
                [expanded]="true"
            >
                <form class="k-form k-form-md">
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatValueAxisTitle') }}</legend>
                        <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                            <kendo-chartwizard-property-pane-form-field
                                inputType="text"
                                [hasLabel]="false"
                                [colSpan]="2"
                                [placeholder]="messageFor('formatValueAxisTitlePlaceholder')"
                                [value]="stateService.state.valueAxis[0]?.title?.text || null"
                                (valueChange)="updateState(valueAxisTitleText, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisTitleFont')"
                                inputType="comboBox"
                                [colSpan]="2"
                                [data]="fontNames"
                                [placeholder]="messageFor('formatValueAxisTitleFontPlaceholder')"
                                [value]="parseFont(stateService.state.valueAxis[0]?.title?.font).name"
                                (valueChange)="updateState(valueAxisTitleFontName, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisTitleSize')"
                                inputType="comboBox"
                                [placeholder]="messageFor('formatValueAxisTitleSizePlaceholder')"
                                [data]="fontSizes"
                                [value]="parseFont(stateService.state.valueAxis[0]?.title?.font).size"
                                (valueChange)="updateState(valueAxisTitleFontSize, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisTitleColor')"
                                inputType="colorPicker"
                                [value]="stateService.state.valueAxis[0]?.title?.color"
                                (valueChange)="updateState(valueAxisTitleColor, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                        </div>
                    </fieldset>
                    <fieldset class="k-form-fieldset">
                        <legend class="k-form-legend">{{ messageFor('formatValueAxisLabels') }}</legend>
                        <div class="k-form-layout k-d-grid k-grid-cols-2 k-gap-x-4">
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisLabelsFormat')"
                                [colSpan]="2"
                                inputType="dropDownList"
                                [data]="labelFormats"
                                [value]="labelFormatValue"
                                (valueChange)="updateState(valueAxisLabelsFormat, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisLabelsFont')"
                                inputType="comboBox"
                                [data]="fontNames"
                                [colSpan]="2"
                                [placeholder]="messageFor('formatValueAxisLabelsFontPlaceholder')"
                                [value]="parseFont(stateService.state.valueAxis[0]?.labels?.font).name"
                                (valueChange)="updateState(valueAxisLabelsFontName, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisLabelsSize')"
                                inputType="comboBox"
                                [data]="fontSizes"
                                [placeholder]="messageFor('formatValueAxisLabelsSizePlaceholder')"
                                [value]="parseFont(stateService.state.valueAxis[0]?.labels?.font).size"
                                (valueChange)="updateState(valueAxisLabelsFontSize, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisLabelsColor')"
                                inputType="colorPicker"
                                [value]="stateService.state.valueAxis[0]?.labels?.color"
                                (valueChange)="updateState(valueAxisLabelsColor, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                            <kendo-chartwizard-property-pane-form-field
                                [text]="messageFor('formatValueAxisLabelsRotation')"
                                inputType="dropDownList"
                                [data]="labelsValueAxisRotation"
                                [value]="stateService.state.valueAxis[0]?.labels?.rotation"
                                (valueChange)="updateState(valueAxisLabelsRotation, $event)"
                            >
                            </kendo-chartwizard-property-pane-form-field>
                        </div>
                    </fieldset>
                </form>
            </kendo-expansionpanel>
        </section>
    `,
                    standalone: true,
                    imports: [
                        ExpansionPanelComponent,
                        ChartWizardPropertyPaneFormFieldComponent,
                        LabelComponent,
                        SwitchComponent,
                        DropDownListComponent,
                        NgIf
                    ]
                }]
        }], ctorParameters: function () { return [{ type: StateService }, { type: ChartWizardLocalizationService }, { type: i0.ChangeDetectorRef }]; } });

/**
 * @hidden
 */
class Messages extends ComponentMessages {
    /**
     * The title of the window.
     */
    windowTitle;
    /**
     * The text of the **Export** DropDownButton.
     */
    exportButton;
    /**
     * The text of the **Export** DropDownButton option that represents PDF.
     */
    exportPDFButton;
    /**
     * The text of the **Export** DropDownButton option that represents SVG.
     */
    exportSVGButton;
    /**
     * The text of the **Export** DropDownButton option that represents PNG.
     */
    exportPNGButton;
    /**
     * The text of the **Chart** tab of the property pane.
     */
    tabChart;
    /**
     * The text of the **Data** tab of the property pane.
     */
    tabData;
    /**
     * The text of the **Format** tab of the property pane.
     */
    tabFormat;
    /**
     * The text of the **Chart** panel that represents Bar Charts.
     */
    barChart;
    /**
     * The text of the Bar Chart type.
     */
    barChartBar;
    /**
     * The text of the Stacked Bar Chart type.
     */
    barChartStackedBar;
    /**
     * The text of the 100% Stacked Bar Chart type.
     */
    barChart100StackedBar;
    /**
     * The text of the **Chart** panel that represents Pie Charts.
     */
    pieChart;
    /**
     * The text of the Pie Chart type.
     */
    pieChartPie;
    /**
     * The text of the **Chart** panel that represents Column Charts.
     */
    columnChart;
    /**
     * The text of the Column Chart type.
     */
    columnChartColumn;
    /**
     * The text of the Stacked Column Chart type.
     */
    columnChartStackedColumn;
    /**
     * The text of the 100% Stacked Column Chart type.
     */
    columnChart100StackedColumn;
    /**
     * The text of the **Chart** panel that represents Line Charts.
     */
    lineChart;
    /**
     * The text of the Line Chart type.
     */
    lineChartLine;
    /**
     * The text of the Stacked Line Chart type.
     */
    lineChartStackedLine;
    /**
     * The text of the 100% Stacked Line Chart type.
     */
    lineChart100StackedLine;
    /**
     * The text of the **Chart** panel that represents Scatter Charts.
     */
    scatterChart;
    /**
     * The text of the Scatter Chart type.
     */
    scatterChartScatter;
    /**
     * The text of the **Configuration** panel of the **Data** tab.
     */
    configuration;
    /**
     * The caption of the **Category Axis** DropDown in the **Configuration** panel.
     */
    configurationCategoryAxis;
    /**
     * The caption of the **X Axis** DropDown in the **Configuration** panel when a Scatter Chart is selected.
     */
    configurationXAxis;
    /**
     * The caption of the **Value Axis** DropDown in the **Configuration** panel when a Pie Chart is selected.
     */
    configurationValueAxis;
    /**
     * The text of the **Series** Grid in the **Configuration** panel when a Categorical Chart is selected.
     */
    configurationSeries;
    /**
     * The text of the **Add Series** button in the Grid of the **Configuration** panel.
     */
    configurationSeriesAdd;
    /**
     * The text of the **Chart Area** panel of the **Format** tab.
     */
    formatChartArea;
    /**
     * The text of the **Margins** settings of the **Chart Area** panel.
     */
    formatChartAreaMargins;
    /**
     * The placeholder of the **Margins** settings of the **Chart Area** panel.
     */
    formatChartAreaMarginsAuto;
    /**
     * The label of the **Left** margin setting of the **Chart Area** panel.
     */
    formatChartAreaMarginsLeft;
    /**
     * The label of the **Right** margin setting of the **Chart Area** panel.
     */
    formatChartAreaMarginsRight;
    /**
     * The label of the **Top** margin setting of the **Chart Area** panel.
     */
    formatChartAreaMarginsTop;
    /**
     * The label of the **Bottom** margin setting of the **Chart Area** panel.
     */
    formatChartAreaMarginsBottom;
    /**
     * The text of the **Background** settings of the **Chart Area** panel.
     */
    formatChartAreaBackground;
    /**
     * The label of the **Color** background setting of the **Chart Area** panel.
     */
    formatChartAreaBackgroundColor;
    /**
     * The text of the **Title** panel of the **Format** tab.
     */
    formatTitle;
    /**
     * The label of the **Apply to** DropDown of the **Title** panel.
     */
    formatTitleApplyTo;
    /**
     * The text of the **Chart Title** option of the **Apply to** DropDown in the **Title** panel.
     */
    formatTitleChartTitle;
    /**
     * The text of the **Chart Subtitle** option of the **Apply to** DropDown in the **Title** panel.
     */
    formatTitleChartSubtitle;
    /**
     * The label of the **Title** input of the **Title** panel.
     */
    formatTitleLabel;
    /**
     * The label of the **Font** setting of the **Title** panel.
     */
    formatTitleFont;
    /**
     * The placeholder of the **Font** setting of the **Title** panel.
     */
    formatTitleFontPlaceholder;
    /**
     * The label of the **Size** setting of the **Title** panel.
     */
    formatTitleSize;
    /**
     * The placeholder of the **Size** setting of the **Title** panel.
     */
    formatTitleSizePlaceholder;
    /**
     * The label of the **Color** setting of the **Title** panel.
     */
    formatTitleColor;
    /**
     * The text of the **Series** panel of the **Format** tab.
     */
    formatSeries;
    /**
     * The label of the **Apply to** DropDown of the **Series** panel.
     */
    formatSeriesApplyTo;
    /**
     * The text of the **All Series** option of the **Apply to** DropDown in the **Series** panel.
     */
    formatSeriesAllSeries;
    /**
     * The label of the **Color** setting of the **Series** panel.
     */
    formatSeriesColor;
    /**
     * The label of the **Show Labels** checkbox of the **Series** panel.
     */
    formatSeriesShowLabels;
    /**
     * The text of the **Legend** panel of the **Format** tab.
     */
    formatLegend;
    /**
     * The label of the **Show Legend** switch of the **Legend** panel.
     */
    formatLegendShowLegend;
    /**
     * The label of the **Font** setting of the **Legend** panel.
     */
    formatLegendFont;
    /**
     * The placeholder of the **Font** setting of the **Legend** panel.
     */
    formatLegendFontPlaceholder;
    /**
     * The label of the **Size** setting of the **Legend** panel.
     */
    formatLegendSize;
    /**
     * The placeholder of the **Size** setting of the **Legend** panel.
     */
    formatLegendSizePlaceholder;
    /**
     * The label of the **Color** setting of the **Legend** panel.
     */
    formatLegendColor;
    /**
     * The label of the **Posititon** DropDown of the **Legend** panel.
     */
    formatLegendPosition;
    /**
     * The text of the **Top** option of the **Position** DropDown of the **Legend** panel.
     */
    formatLegendPositionTop;
    /**
     * The text of the **Bottom** option of the **Position** DropDown of the **Legend** panel.
     */
    formatLegendPositionBottom;
    /**
     * The text of the **Left** option of the **Position** DropDown of the **Legend** panel.
     */
    formatLegendPositionLeft;
    /**
     * The text of the **Right** option of the **Position** DropDown of the **Legend** panel.
     */
    formatLegendPositionRight;
    /**
     * The text of the **Category Axis** panel of the **Format** tab.
     */
    formatCategoryAxis;
    /**
     * The text of the **X Axis** panel of the **Format** tab when a Scatter Chart is selected.
     */
    formatXAxis;
    /**
     * The label of the **Title** settings of the **Category Axis** panel.
     */
    formatCategoryAxisTitle;
    /**
     * The placeholder of the **Title** input of the **Category Axis** panel.
     */
    formatCategoryAxisTitlePlaceholder;
    /**
     * The label of the **Font** settings of the **Title** in the **Category Axis** panel.
     */
    formatCategoryAxisTitleFont;
    /**
     * The placeholder of the **Font** settings of the **Title** in the **Category Axis** panel.
     */
    formatCategoryAxisTitleFontPlaceholder;
    /**
     * The label of the **Size** settings of the **Title** in the **Category Axis** panel.
     */
    formatCategoryAxisTitleSize;
    /**
     * The placeholder of the **Size** settings of the **Title** in the **Category Axis** panel.
     */
    formatCategoryAxisTitleSizePlaceholder;
    /**
     * The label of the **Color** settings of the **Title** in the **Category Axis** panel.
     */
    formatCategoryAxisTitleColor;
    /**
     * The label of the **Labels** settings of the **Category Axis** panel.
     */
    formatCategoryAxisLabels;
    /**
     * The label of the **Font** settings of the **Labels** in the **Category Axis** panel.
     */
    formatCategoryAxisLabelsFont;
    /**
     * The placeholder of the **Font** settings of the **Labels** in the **Category Axis** panel.
     */
    formatCategoryAxisLabelsFontPlaceholder;
    /**
     * The label of the **Size** settings of the **Labels** in the **Category Axis** panel.
     */
    formatCategoryAxisLabelsSize;
    /**
     * The placeholder of the **Size** settings of the **Labels** in the **Category Axis** panel.
     */
    formatCategoryAxisLabelsSizePlaceholder;
    /**
     * The label of the **Color** settings of the **Labels** in the **Category Axis** panel.
     */
    formatCategoryAxisLabelsColor;
    /**
     * The label of the **Rotation** settings of the **Labels** in the **Category Axis** panel.
     */
    formatCategoryAxisLabelsRotation;
    /**
     * The **Auto** option of the **Rotation** settings of the **Labels** in the **Category Axis** panel.
     */
    formatCategoryAxisLabelsRotationAuto;
    /**
     * The label of the **Reverse Order** checkbox of the **Labels** in the **Category Axis** panel.
     */
    formatCategoryAxisLabelsReverseOrder;
    /**
     * The text of the **Value Axis** panel of the **Format** tab.
     */
    formatValueAxis;
    /**
     * The text of the **Y Axis** panel of the **Format** tab.
     */
    formatYAxis;
    /**
     * The label of the **Title** settings of the **Value Axis** panel.
     */
    formatValueAxisTitle;
    /**
     * The placeholder of the **Title** settings of the **Value Axis** panel.
     */
    formatValueAxisTitlePlaceholder;
    /**
     * The label of the **Font** settings of the **Value Axis** panel.
     */
    formatValueAxisTitleFont;
    /**
     * The placeholder of the **Font** settings of the **Value Axis** panel.
     */
    formatValueAxisTitleFontPlaceholder;
    /**
     * The label of the **Size** settings of the **Value Axis** panel.
     */
    formatValueAxisTitleSize;
    /**
     * The placeholder of the **Size** settings of the **Value Axis** panel.
     */
    formatValueAxisTitleSizePlaceholder;
    /**
     * The label of the **Color** settings of the **Value Axis** panel.
     */
    formatValueAxisTitleColor;
    /**
     * The label of the **Labels** settings of the **Value Axis** panel.
     */
    formatValueAxisLabels;
    /**
     * The label of the **Format** DropDown of the **Labels** settings of the **Value Axis** panel.
     */
    formatValueAxisLabelsFormat;
    /**
     * The **Text** option of the **Format** DropDown of the **Labels** settings of the **Value Axis** panel.
     */
    formatValueAxisLabelsFormatText;
    /**
     * The **Number** option of the **Format** DropDown of the **Labels** settings of the **Value Axis** panel.
     */
    formatValueAxisLabelsFormatNumber;
    /**
     * The **Currency** option of the **Format** DropDown of the **Labels** settings of the **Value Axis** panel.
     */
    formatValueAxisLabelsFormatCurrency;
    /**
     * The **Percent** option of the **Format** DropDown of the **Labels** settings of the **Value Axis** panel.
     */
    formatValueAxisLabelsFormatPercent;
    /**
     * The label of the **Font** settings of the **Labels** in the **Value Axis** panel.
     */
    formatValueAxisLabelsFont;
    /**
     * The placeholder of the **Font** settings of the **Labels** in the **Value Axis** panel.
     */
    formatValueAxisLabelsFontPlaceholder;
    /**
     * The label of the **Size** settings of the **Labels** in the **Value Axis** panel.
     */
    formatValueAxisLabelsSize;
    /**
     * The placeholder of the **Size** settings of the **Labels** in the **Value Axis** panel.
     */
    formatValueAxisLabelsSizePlaceholder;
    /**
     * The label of the **Color** settings of the **Labels** in the **Value Axis** panel.
     */
    formatValueAxisLabelsColor;
    /**
     * The label of the **Rotation** settings of the **Labels** in the **Value Axis** panel.
     */
    formatValueAxisLabelsRotation;
    /**
     * The **Auto** option of the **Rotation** settings of the **Labels** in the **Value Axis** panel.
     */
    formatValueAxisLabelsRotationAuto;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages, deps: null, target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: Messages, selector: "[kendoChartWizardMessages]", inputs: { windowTitle: "windowTitle", exportButton: "exportButton", exportPDFButton: "exportPDFButton", exportSVGButton: "exportSVGButton", exportPNGButton: "exportPNGButton", tabChart: "tabChart", tabData: "tabData", tabFormat: "tabFormat", barChart: "barChart", barChartBar: "barChartBar", barChartStackedBar: "barChartStackedBar", barChart100StackedBar: "barChart100StackedBar", pieChart: "pieChart", pieChartPie: "pieChartPie", columnChart: "columnChart", columnChartColumn: "columnChartColumn", columnChartStackedColumn: "columnChartStackedColumn", columnChart100StackedColumn: "columnChart100StackedColumn", lineChart: "lineChart", lineChartLine: "lineChartLine", lineChartStackedLine: "lineChartStackedLine", lineChart100StackedLine: "lineChart100StackedLine", scatterChart: "scatterChart", scatterChartScatter: "scatterChartScatter", configuration: "configuration", configurationCategoryAxis: "configurationCategoryAxis", configurationXAxis: "configurationXAxis", configurationValueAxis: "configurationValueAxis", configurationSeries: "configurationSeries", configurationSeriesAdd: "configurationSeriesAdd", formatChartArea: "formatChartArea", formatChartAreaMargins: "formatChartAreaMargins", formatChartAreaMarginsAuto: "formatChartAreaMarginsAuto", formatChartAreaMarginsLeft: "formatChartAreaMarginsLeft", formatChartAreaMarginsRight: "formatChartAreaMarginsRight", formatChartAreaMarginsTop: "formatChartAreaMarginsTop", formatChartAreaMarginsBottom: "formatChartAreaMarginsBottom", formatChartAreaBackground: "formatChartAreaBackground", formatChartAreaBackgroundColor: "formatChartAreaBackgroundColor", formatTitle: "formatTitle", formatTitleApplyTo: "formatTitleApplyTo", formatTitleChartTitle: "formatTitleChartTitle", formatTitleChartSubtitle: "formatTitleChartSubtitle", formatTitleLabel: "formatTitleLabel", formatTitleFont: "formatTitleFont", formatTitleFontPlaceholder: "formatTitleFontPlaceholder", formatTitleSize: "formatTitleSize", formatTitleSizePlaceholder: "formatTitleSizePlaceholder", formatTitleColor: "formatTitleColor", formatSeries: "formatSeries", formatSeriesApplyTo: "formatSeriesApplyTo", formatSeriesAllSeries: "formatSeriesAllSeries", formatSeriesColor: "formatSeriesColor", formatSeriesShowLabels: "formatSeriesShowLabels", formatLegend: "formatLegend", formatLegendShowLegend: "formatLegendShowLegend", formatLegendFont: "formatLegendFont", formatLegendFontPlaceholder: "formatLegendFontPlaceholder", formatLegendSize: "formatLegendSize", formatLegendSizePlaceholder: "formatLegendSizePlaceholder", formatLegendColor: "formatLegendColor", formatLegendPosition: "formatLegendPosition", formatLegendPositionTop: "formatLegendPositionTop", formatLegendPositionBottom: "formatLegendPositionBottom", formatLegendPositionLeft: "formatLegendPositionLeft", formatLegendPositionRight: "formatLegendPositionRight", formatCategoryAxis: "formatCategoryAxis", formatXAxis: "formatXAxis", formatCategoryAxisTitle: "formatCategoryAxisTitle", formatCategoryAxisTitlePlaceholder: "formatCategoryAxisTitlePlaceholder", formatCategoryAxisTitleFont: "formatCategoryAxisTitleFont", formatCategoryAxisTitleFontPlaceholder: "formatCategoryAxisTitleFontPlaceholder", formatCategoryAxisTitleSize: "formatCategoryAxisTitleSize", formatCategoryAxisTitleSizePlaceholder: "formatCategoryAxisTitleSizePlaceholder", formatCategoryAxisTitleColor: "formatCategoryAxisTitleColor", formatCategoryAxisLabels: "formatCategoryAxisLabels", formatCategoryAxisLabelsFont: "formatCategoryAxisLabelsFont", formatCategoryAxisLabelsFontPlaceholder: "formatCategoryAxisLabelsFontPlaceholder", formatCategoryAxisLabelsSize: "formatCategoryAxisLabelsSize", formatCategoryAxisLabelsSizePlaceholder: "formatCategoryAxisLabelsSizePlaceholder", formatCategoryAxisLabelsColor: "formatCategoryAxisLabelsColor", formatCategoryAxisLabelsRotation: "formatCategoryAxisLabelsRotation", formatCategoryAxisLabelsRotationAuto: "formatCategoryAxisLabelsRotationAuto", formatCategoryAxisLabelsReverseOrder: "formatCategoryAxisLabelsReverseOrder", formatValueAxis: "formatValueAxis", formatYAxis: "formatYAxis", formatValueAxisTitle: "formatValueAxisTitle", formatValueAxisTitlePlaceholder: "formatValueAxisTitlePlaceholder", formatValueAxisTitleFont: "formatValueAxisTitleFont", formatValueAxisTitleFontPlaceholder: "formatValueAxisTitleFontPlaceholder", formatValueAxisTitleSize: "formatValueAxisTitleSize", formatValueAxisTitleSizePlaceholder: "formatValueAxisTitleSizePlaceholder", formatValueAxisTitleColor: "formatValueAxisTitleColor", formatValueAxisLabels: "formatValueAxisLabels", formatValueAxisLabelsFormat: "formatValueAxisLabelsFormat", formatValueAxisLabelsFormatText: "formatValueAxisLabelsFormatText", formatValueAxisLabelsFormatNumber: "formatValueAxisLabelsFormatNumber", formatValueAxisLabelsFormatCurrency: "formatValueAxisLabelsFormatCurrency", formatValueAxisLabelsFormatPercent: "formatValueAxisLabelsFormatPercent", formatValueAxisLabelsFont: "formatValueAxisLabelsFont", formatValueAxisLabelsFontPlaceholder: "formatValueAxisLabelsFontPlaceholder", formatValueAxisLabelsSize: "formatValueAxisLabelsSize", formatValueAxisLabelsSizePlaceholder: "formatValueAxisLabelsSizePlaceholder", formatValueAxisLabelsColor: "formatValueAxisLabelsColor", formatValueAxisLabelsRotation: "formatValueAxisLabelsRotation", formatValueAxisLabelsRotationAuto: "formatValueAxisLabelsRotationAuto" }, usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoChartWizardMessages]'
                }]
        }], propDecorators: { windowTitle: [{
                type: Input
            }], exportButton: [{
                type: Input
            }], exportPDFButton: [{
                type: Input
            }], exportSVGButton: [{
                type: Input
            }], exportPNGButton: [{
                type: Input
            }], tabChart: [{
                type: Input
            }], tabData: [{
                type: Input
            }], tabFormat: [{
                type: Input
            }], barChart: [{
                type: Input
            }], barChartBar: [{
                type: Input
            }], barChartStackedBar: [{
                type: Input
            }], barChart100StackedBar: [{
                type: Input
            }], pieChart: [{
                type: Input
            }], pieChartPie: [{
                type: Input
            }], columnChart: [{
                type: Input
            }], columnChartColumn: [{
                type: Input
            }], columnChartStackedColumn: [{
                type: Input
            }], columnChart100StackedColumn: [{
                type: Input
            }], lineChart: [{
                type: Input
            }], lineChartLine: [{
                type: Input
            }], lineChartStackedLine: [{
                type: Input
            }], lineChart100StackedLine: [{
                type: Input
            }], scatterChart: [{
                type: Input
            }], scatterChartScatter: [{
                type: Input
            }], configuration: [{
                type: Input
            }], configurationCategoryAxis: [{
                type: Input
            }], configurationXAxis: [{
                type: Input
            }], configurationValueAxis: [{
                type: Input
            }], configurationSeries: [{
                type: Input
            }], configurationSeriesAdd: [{
                type: Input
            }], formatChartArea: [{
                type: Input
            }], formatChartAreaMargins: [{
                type: Input
            }], formatChartAreaMarginsAuto: [{
                type: Input
            }], formatChartAreaMarginsLeft: [{
                type: Input
            }], formatChartAreaMarginsRight: [{
                type: Input
            }], formatChartAreaMarginsTop: [{
                type: Input
            }], formatChartAreaMarginsBottom: [{
                type: Input
            }], formatChartAreaBackground: [{
                type: Input
            }], formatChartAreaBackgroundColor: [{
                type: Input
            }], formatTitle: [{
                type: Input
            }], formatTitleApplyTo: [{
                type: Input
            }], formatTitleChartTitle: [{
                type: Input
            }], formatTitleChartSubtitle: [{
                type: Input
            }], formatTitleLabel: [{
                type: Input
            }], formatTitleFont: [{
                type: Input
            }], formatTitleFontPlaceholder: [{
                type: Input
            }], formatTitleSize: [{
                type: Input
            }], formatTitleSizePlaceholder: [{
                type: Input
            }], formatTitleColor: [{
                type: Input
            }], formatSeries: [{
                type: Input
            }], formatSeriesApplyTo: [{
                type: Input
            }], formatSeriesAllSeries: [{
                type: Input
            }], formatSeriesColor: [{
                type: Input
            }], formatSeriesShowLabels: [{
                type: Input
            }], formatLegend: [{
                type: Input
            }], formatLegendShowLegend: [{
                type: Input
            }], formatLegendFont: [{
                type: Input
            }], formatLegendFontPlaceholder: [{
                type: Input
            }], formatLegendSize: [{
                type: Input
            }], formatLegendSizePlaceholder: [{
                type: Input
            }], formatLegendColor: [{
                type: Input
            }], formatLegendPosition: [{
                type: Input
            }], formatLegendPositionTop: [{
                type: Input
            }], formatLegendPositionBottom: [{
                type: Input
            }], formatLegendPositionLeft: [{
                type: Input
            }], formatLegendPositionRight: [{
                type: Input
            }], formatCategoryAxis: [{
                type: Input
            }], formatXAxis: [{
                type: Input
            }], formatCategoryAxisTitle: [{
                type: Input
            }], formatCategoryAxisTitlePlaceholder: [{
                type: Input
            }], formatCategoryAxisTitleFont: [{
                type: Input
            }], formatCategoryAxisTitleFontPlaceholder: [{
                type: Input
            }], formatCategoryAxisTitleSize: [{
                type: Input
            }], formatCategoryAxisTitleSizePlaceholder: [{
                type: Input
            }], formatCategoryAxisTitleColor: [{
                type: Input
            }], formatCategoryAxisLabels: [{
                type: Input
            }], formatCategoryAxisLabelsFont: [{
                type: Input
            }], formatCategoryAxisLabelsFontPlaceholder: [{
                type: Input
            }], formatCategoryAxisLabelsSize: [{
                type: Input
            }], formatCategoryAxisLabelsSizePlaceholder: [{
                type: Input
            }], formatCategoryAxisLabelsColor: [{
                type: Input
            }], formatCategoryAxisLabelsRotation: [{
                type: Input
            }], formatCategoryAxisLabelsRotationAuto: [{
                type: Input
            }], formatCategoryAxisLabelsReverseOrder: [{
                type: Input
            }], formatValueAxis: [{
                type: Input
            }], formatYAxis: [{
                type: Input
            }], formatValueAxisTitle: [{
                type: Input
            }], formatValueAxisTitlePlaceholder: [{
                type: Input
            }], formatValueAxisTitleFont: [{
                type: Input
            }], formatValueAxisTitleFontPlaceholder: [{
                type: Input
            }], formatValueAxisTitleSize: [{
                type: Input
            }], formatValueAxisTitleSizePlaceholder: [{
                type: Input
            }], formatValueAxisTitleColor: [{
                type: Input
            }], formatValueAxisLabels: [{
                type: Input
            }], formatValueAxisLabelsFormat: [{
                type: Input
            }], formatValueAxisLabelsFormatText: [{
                type: Input
            }], formatValueAxisLabelsFormatNumber: [{
                type: Input
            }], formatValueAxisLabelsFormatCurrency: [{
                type: Input
            }], formatValueAxisLabelsFormatPercent: [{
                type: Input
            }], formatValueAxisLabelsFont: [{
                type: Input
            }], formatValueAxisLabelsFontPlaceholder: [{
                type: Input
            }], formatValueAxisLabelsSize: [{
                type: Input
            }], formatValueAxisLabelsSizePlaceholder: [{
                type: Input
            }], formatValueAxisLabelsColor: [{
                type: Input
            }], formatValueAxisLabelsRotation: [{
                type: Input
            }], formatValueAxisLabelsRotationAuto: [{
                type: Input
            }] } });

/**
 * @hidden
 */
class LocalizedMessagesDirective extends Messages {
    service;
    constructor(service) {
        super();
        this.service = service;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LocalizedMessagesDirective, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: LocalizedMessagesDirective, isStandalone: true, selector: "[kendoChartWizardLocalizedMessages]", providers: [
            {
                provide: Messages,
                useExisting: forwardRef(() => LocalizedMessagesDirective)
            }
        ], usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LocalizedMessagesDirective, decorators: [{
            type: Directive,
            args: [{
                    providers: [
                        {
                            provide: Messages,
                            useExisting: forwardRef(() => LocalizedMessagesDirective)
                        }
                    ],
                    selector: '[kendoChartWizardLocalizedMessages]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; } });

/**
 * Represents the Kendo UI for Angular Chart Wizard component.
 *
 * @example
 * ```html
 *  <kendo-chartwizard [data]="data"></kendo-chartwizard>
 * ```
 */
class ChartWizardComponent {
    localization;
    stateService;
    /**
     * The data to display in the Chart Wizard.
     */
    data;
    /**
     * Sets the default state of the Chart Wizard.
     */
    defaultState;
    /**
     * The Chart Wizard export options.
     */
    exportOptions;
    /**
     * Specifies if the configuration pane is initially collapsed.
     * @default false
     */
    collapsedConfigurationPane = false;
    /**
     * The settings of the window.
     */
    windowSettings = {};
    /**
     * @hidden
     */
    showLicenseWatermark = false;
    /**
     * @hidden
     */
    exportIcon = exportIcon;
    /**
     * @hidden
     */
    exportDropdownItems = [];
    /**
     * Fires when the Chart Wizard Window is to be close.
     */
    close = new EventEmitter();
    /**
     * Fires when the Chart is about to be exported. The event is preventable.
     */
    export = new EventEmitter();
    get dir() {
        return this.stateService.direction;
    }
    /**
     * @hidden
     */
    chart;
    /**
     * @hidden
     */
    propertyPane;
    /**
     * @hidden
     */
    dataTab;
    /**
     * @hidden
     */
    messages = ChartWizardCommon.messages;
    subscription = new Subscription();
    constructor(localization, stateService) {
        this.localization = localization;
        this.stateService = stateService;
        const isValid = validatePackage(packageMetadata);
        this.showLicenseWatermark = shouldShowValidationUI(isValid);
        this.stateService.direction = this.localization.rtl ? 'rtl' : 'ltr';
    }
    ngAfterViewInit() {
        this.subscription.add(this.localization.changes.subscribe(({ rtl }) => {
            this.stateService.direction = rtl ? 'rtl' : 'ltr';
            this.exportDropdownItems = [
                {
                    text: this.messageFor('exportPDFButton'),
                    svgIcon: filePdfIcon,
                },
                {
                    text: this.messageFor('exportSVGButton'),
                    svgIcon: fileIcon,
                },
                {
                    text: this.messageFor('exportPNGButton'),
                    svgIcon: fileImageIcon,
                },
            ];
        }));
        this.stateService.dataTab = this.dataTab;
    }
    ngOnChanges(changes) {
        if (changes['data'] && changes['data'].currentValue?.length > 0) {
            const data = changes['data'].currentValue;
            const clonedData = structuredClone(data);
            this.stateService.data = clonedData;
            this.stateService.state = createState(clonedData, this.stateService.state.seriesType);
        }
        if (changes['defaultState'] && this.data?.length > 0) {
            const defaultState = changes['defaultState'].currentValue;
            if (defaultState.seriesType) {
                this.stateService.state.seriesType = defaultState.seriesType;
                this.stateService.state = mergeStates(this.stateService.state, createState(this.stateService.data, this.stateService.state.seriesType));
            }
            this.stateService.currentSeries = defaultAllSeriesItem;
            if (typeof defaultState.stack !== 'undefined') {
                this.stateService.state = updateState(this.stateService.state, ActionTypes.stacked, defaultState.stack);
            }
            this.propertyPane?.detectChanges();
        }
    }
    ngOnDestroy() {
        if (this.subscription) {
            this.subscription.unsubscribe();
        }
    }
    /**
     * @hidden
     */
    messageFor(key) {
        return this.localization.get(key);
    }
    /**
     * @hidden
     */
    onExport(exportType) {
        const args = new ExportEvent(this.chart, this.exportOptions);
        this.export.emit(args);
        if (args.isDefaultPrevented()) {
            return;
        }
        switch (exportType.text) {
            case 'PDF File':
                exportPDF(this.chart.exportVisual(), this.exportOptions?.pdf).then((dataURI) => {
                    saveAs(dataURI, this.exportOptions?.fileName || 'chart');
                });
                break;
            case 'SVG File':
                this.chart.exportSVG(this.exportOptions?.image).then((dataURI) => {
                    saveAs(dataURI, this.exportOptions?.fileName || 'chart');
                });
                break;
            case 'PNG File':
                this.chart.exportImage(this.exportOptions?.image).then((dataURI) => {
                    saveAs(dataURI, this.exportOptions?.fileName || 'chart');
                });
                break;
        }
    }
    /**
     * @hidden
     */
    get windowWidth() {
        return isPresent(this.windowSettings?.width) ? this.windowSettings.width : this.stateService.windowSize.width;
    }
    /**
     * @hidden
     */
    get windowHeight() {
        return isPresent(this.windowSettings?.height) ? this.windowSettings.height : this.stateService.windowSize.height;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardComponent, deps: [{ token: i1.LocalizationService }, { token: StateService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ChartWizardComponent, isStandalone: true, selector: "kendo-chartwizard", inputs: { data: "data", defaultState: "defaultState", exportOptions: "exportOptions", collapsedConfigurationPane: "collapsedConfigurationPane", windowSettings: "windowSettings" }, outputs: { close: "close", export: "export" }, host: { properties: { "attr.dir": "this.dir" } }, providers: [
            LocalizationService,
            {
                provide: L10N_PREFIX,
                useValue: 'kendo.chartwizard',
            },
            ChartWizardLocalizationService,
            {
                provide: LocalizationService,
                useExisting: ChartWizardLocalizationService
            },
            StateService
        ], viewQueries: [{ propertyName: "chart", first: true, predicate: ChartComponent, descendants: true }, { propertyName: "propertyPane", first: true, predicate: ChartWizardPropertyPaneChartTabComponent, descendants: true }, { propertyName: "dataTab", first: true, predicate: ChartWizardPropertyPaneDataTabComponent, descendants: true }], exportAs: ["kendoChartWizard"], usesOnChanges: true, ngImport: i0, template: `
        <ng-container
            kendoChartWizardLocalizedMessages

            i18n-windowTitle="kendo.chartwizard.windowTitle|The title of the window."
            [windowTitle]="messages.windowTitle"

            i18n-exportButton="kendo.chartwizard.exportButton|The text of the Export DropDownButton."
            [exportButton]="messages.exportButton"

            i18n-exportPDFButton="kendo.chartwizard.exportPDFButton|The text of the Export DropDownButton option that represents PDF."
            [exportPDFButton]="messages.exportPDFButton"

            i18n-exportSVGButton="kendo.chartwizard.exportSVGButton|The text of the Export DropDownButton option that represents SVG."
            [exportSVGButton]="messages.exportSVGButton"

            i18n-exportPNGButton="kendo.chartwizard.exportPNGButton|The text of the Export DropDownButton option that represents PNG."
            [exportPNGButton]="messages.exportPNGButton"

            i18n-tabChart="kendo.chartwizard.tabChart|The text of the Chart tab of the property pane."
            [tabChart]="messages.tabChart"

            i18n-tabData="kendo.chartwizard.tabData|The text of the Data tab of the property pane."
            [tabData]="messages.tabData"

            i18n-tabFormat="kendo.chartwizard.tabFormat|The text of the Format tab of the property pane."
            [tabFormat]="messages.tabFormat"

            i18n-barChart="kendo.chartwizard.barChart|The text of the Chart panel that represents Bar Charts."
            [barChart]="messages.barChart"

            i18n-barChartBar="kendo.chartwizard.barChartBar|The text of the Bar Chart type."
            [barChartBar]="messages.barChartBar"

            i18n-barChartStackedBar="kendo.chartwizard.barChartStackedBar|The text of the Stacked Bar Chart type."
            [barChartStackedBar]="messages.barChartStackedBar"

            i18n-barChart100StackedBar="kendo.chartwizard.barChart100StackedBar|The text of the 100% Stacked Bar Chart type."
            [barChart100StackedBar]="messages.barChart100StackedBar"

            i18n-pieChart="kendo.chartwizard.pieChart|The text of the Chart panel that represents Pie Charts."
            [pieChart]="messages.pieChart"

            i18n-pieChartPie="kendo.chartwizard.pieChartPie|The text of the Pie Chart type."
            [pieChartPie]="messages.pieChartPie"

            i18n-columnChart="kendo.chartwizard.columnChart|The text of the Chart panel that represents Column Charts."
            [columnChart]="messages.columnChart"

            i18n-columnChartColumn="kendo.chartwizard.columnChartColumn|The text of the Column Chart type."
            [columnChartColumn]="messages.columnChartColumn"

            i18n-columnChartStackedColumn="kendo.chartwizard.columnChartStackedColumn|The text of the Stacked Column Chart type."
            [columnChartStackedColumn]="messages.columnChartStackedColumn"

            i18n-columnChart100StackedColumn="kendo.chartwizard.columnChart100StackedColumn|The text of the 100% Stacked Column Chart type."
            [columnChart100StackedColumn]="messages.columnChart100StackedColumn"

            i18n-lineChart="kendo.chartwizard.lineChart|The text of the Chart panel that represents Line Charts."
            [lineChart]="messages.lineChart"

            i18n-lineChartLine="kendo.chartwizard.lineChartLine|The text of the Line Chart type."
            [lineChartLine]="messages.lineChartLine"

            i18n-lineChartStackedLine="kendo.chartwizard.lineChartStackedLine|The text of the Stacked Line Chart type."
            [lineChartStackedLine]="messages.lineChartStackedLine"

            i18n-lineChart100StackedLine="kendo.chartwizard.lineChart100StackedLine|The text of the 100% Stacked Line Chart type."
            [lineChart100StackedLine]="messages.lineChart100StackedLine"

            i18n-scatterChart="kendo.chartwizard.scatterChart|The text of the Chart panel that represents Scatter Charts."
            [scatterChart]="messages.scatterChart"

            i18n-scatterChartScatter="kendo.chartwizard.scatterChartScatter|The text of the Scatter Chart type."
            [scatterChartScatter]="messages.scatterChartScatter"

            i18n-configuration="kendo.chartwizard.configuration|The text of the Configuration panel of the Data tab."
            [configuration]="messages.configuration"

            i18n-configurationCategoryAxis="kendo.chartwizard.configurationCategoryAxis|The caption of the Category Axis DropDown in the Configuration panel."
            [configurationCategoryAxis]="messages.configurationCategoryAxis"

            i18n-configurationXAxis="kendo.chartwizard.configurationXAxis|The caption of the X Axis DropDown in the Configuration panel when a Scatter Chart is selected."
            [configurationXAxis]="messages.configurationXAxis"

            i18n-configurationValueAxis="kendo.chartwizard.configurationValueAxis|The caption of the Value Axis DropDown in the Configuration panel when a Pie Chart is selected."
            [configurationValueAxis]="messages.configurationValueAxis"

            i18n-configurationSeries="kendo.chartwizard.configurationSeries|The text of the Series Grid in the Configuration panel when a Categorical Chart is selected."
            [configurationSeries]="messages.configurationSeries"

            i18n-configurationSeriesAdd="kendo.chartwizard.configurationSeriesAdd|The text of the Add Series button in the Grid of the Configuration panel."
            [configurationSeriesAdd]="messages.configurationSeriesAdd"

            i18n-formatChartArea="kendo.chartwizard.formatChartArea|The text of the Chart Area panel of the Format tab."
            [formatChartArea]="messages.formatChartArea"

            i18n-formatChartAreaMargins="kendo.chartwizard.formatChartAreaMargins|The text of the Margins settings of the Chart Area panel."
            [formatChartAreaMargins]="messages.formatChartAreaMargins"

            i18n-formatChartAreaMarginsAuto="kendo.chartwizard.formatChartAreaMarginsAuto|The placeholder of the Margins settings of the Chart Area panel."
            [formatChartAreaMarginsAuto]="messages.formatChartAreaMarginsAuto"

            i18n-formatChartAreaMarginsLeft="kendo.chartwizard.formatChartAreaMarginsLeft|The label of the Left margin setting of the Chart Area panel."
            [formatChartAreaMarginsLeft]="messages.formatChartAreaMarginsLeft"

            i18n-formatChartAreaMarginsRight="kendo.chartwizard.formatChartAreaMarginsRight|The label of the Right margin setting of the Chart Area panel."
            [formatChartAreaMarginsRight]="messages.formatChartAreaMarginsRight"

            i18n-formatChartAreaMarginsTop="kendo.chartwizard.formatChartAreaMarginsTop|The label of the Top margin setting of the Chart Area panel."
            [formatChartAreaMarginsTop]="messages.formatChartAreaMarginsTop"

            i18n-formatChartAreaMarginsBottom="kendo.chartwizard.formatChartAreaMarginsBottom|The label of the Bottom margin setting of the Chart Area panel."
            [formatChartAreaMarginsBottom]="messages.formatChartAreaMarginsBottom"

            i18n-formatChartAreaBackground="kendo.chartwizard.formatChartAreaBackground|The text of the Background settings of the Chart Area panel."
            [formatChartAreaBackground]="messages.formatChartAreaBackground"

            i18n-formatChartAreaBackgroundColor="kendo.chartwizard.formatChartAreaBackgroundColor|The label of the Color background setting of the Chart Area panel."
            [formatChartAreaBackgroundColor]="messages.formatChartAreaBackgroundColor"

            i18n-formatTitle="kendo.chartwizard.formatTitle|The text of the Title panel of the Format tab."
            [formatTitle]="messages.formatTitle"

            i18n-formatTitleApplyTo="kendo.chartwizard.formatTitleApplyTo|The label of the Apply to DropDown of the Title panel."
            [formatTitleApplyTo]="messages.formatTitleApplyTo"

            i18n-formatTitleChartTitle="kendo.chartwizard.formatTitleChartTitle|The text of the Chart Title option of the Apply to DropDown in the Title panel."
            [formatTitleChartTitle]="messages.formatTitleChartTitle"

            i18n-formatTitleChartSubtitle="kendo.chartwizard.formatTitleChartSubtitle|The text of the Chart Subtitle option of the Apply to DropDown in the Title panel."
            [formatTitleChartSubtitle]="messages.formatTitleChartSubtitle"

            i18n-formatTitleLabel="kendo.chartwizard.formatTitleLabel|The label of the Title input of the Title panel."
            [formatTitleLabel]="messages.formatTitleLabel"

            i18n-formatTitleFont="kendo.chartwizard.formatTitleFont|The label of the Font setting of the Title panel."
            [formatTitleFont]="messages.formatTitleFont"

            i18n-formatTitleFontPlaceholder="kendo.chartwizard.formatTitleFontPlaceholder|The placeholder of the Font setting of the Title panel."
            [formatTitleFontPlaceholder]="messages.formatTitleFontPlaceholder"

            i18n-formatTitleSize="kendo.chartwizard.formatTitleSize|The label of the Size setting of the Title panel."
            [formatTitleSize]="messages.formatTitleSize"

            i18n-formatTitleSizePlaceholder="kendo.chartwizard.formatTitleSizePlaceholder|The placeholder of the Size setting of the Title panel."
            [formatTitleSizePlaceholder]="messages.formatTitleSizePlaceholder"

            i18n-formatTitleColor="kendo.chartwizard.formatTitleColor|The label of the Color setting of the Title panel."
            [formatTitleColor]="messages.formatTitleColor"

            i18n-formatSeries="kendo.chartwizard.formatSeries|The text of the Series panel of the Format tab."
            [formatSeries]="messages.formatSeries"

            i18n-formatSeriesApplyTo="kendo.chartwizard.formatSeriesApplyTo|The label of the Apply to DropDown of the Series panel."
            [formatSeriesApplyTo]="messages.formatSeriesApplyTo"

            i18n-formatSeriesAllSeries="kendo.chartwizard.formatSeriesAllSeries|The text of the All Series option of the Apply to DropDown in the Series panel."
            [formatSeriesAllSeries]="messages.formatSeriesAllSeries"

            i18n-formatSeriesColor="kendo.chartwizard.formatSeriesColor|The label of the Color setting of the Series panel."
            [formatSeriesColor]="messages.formatSeriesColor"

            i18n-formatSeriesShowLabels="kendo.chartwizard.formatSeriesShowLabels|The label of the Show Labels checkbox of the Series panel."
            [formatSeriesShowLabels]="messages.formatSeriesShowLabels"

            i18n-formatLegend="kendo.chartwizard.formatLegend|The text of the Legend panel of the Format tab."
            [formatLegend]="messages.formatLegend"

            i18n-formatLegendShowLegend="kendo.chartwizard.formatLegendShowLegend|The label of the Show Legend switch of the Legend panel."
            [formatLegendShowLegend]="messages.formatLegendShowLegend"

            i18n-formatLegendFont="kendo.chartwizard.formatLegendFont|The label of the Font setting of the Legend panel."
            [formatLegendFont]="messages.formatLegendFont"

            i18n-formatLegendFontPlaceholder="kendo.chartwizard.formatLegendFontPlaceholder|The placeholder of the Font setting of the Legend panel."
            [formatLegendFontPlaceholder]="messages.formatLegendFontPlaceholder"

            i18n-formatLegendSize="kendo.chartwizard.formatLegendSize|The label of the Size setting of the Legend panel."
            [formatLegendSize]="messages.formatLegendSize"

            i18n-formatLegendSizePlaceholder="kendo.chartwizard.formatLegendSizePlaceholder|The placeholder of the Size setting of the Legend panel."
            [formatLegendSizePlaceholder]="messages.formatLegendSizePlaceholder"

            i18n-formatLegendColor="kendo.chartwizard.formatLegendColor|The label of the Color setting of the Legend panel."
            [formatLegendColor]="messages.formatLegendColor"

            i18n-formatLegendPosition="kendo.chartwizard.formatLegendPosition|The label of the Posiiton DropDown of the Legend panel."
            [formatLegendPosition]="messages.formatLegendPosition"

            i18n-formatLegendPositionTop="kendo.chartwizard.formatLegendPositionTop|The text of the Top option of the Position DropDown of the Legend panel."
            [formatLegendPositionTop]="messages.formatLegendPositionTop"

            i18n-formatLegendPositionBottom="kendo.chartwizard.formatLegendPositionBottom|The text of the Bottom option of the Position DropDown of the Legend panel."
            [formatLegendPositionBottom]="messages.formatLegendPositionBottom"

            i18n-formatLegendPositionLeft="kendo.chartwizard.formatLegendPositionLeft|The text of the Left option of the Position DropDown of the Legend panel."
            [formatLegendPositionLeft]="messages.formatLegendPositionLeft"

            i18n-formatLegendPositionRight="kendo.chartwizard.formatLegendPositionRight|The text of the Right option of the Position DropDown of the Legend panel."
            [formatLegendPositionRight]="messages.formatLegendPositionRight"

            i18n-formatCategoryAxis="kendo.chartwizard.formatCategoryAxis|The text of the Category Axis panel of the Format tab."
            [formatCategoryAxis]="messages.formatCategoryAxis"

            i18n-formatXAxis="kendo.chartwizard.formatXAxis|The text of the X Axis panel of the Format tab when a Scatter Chart is selected."
            [formatXAxis]="messages.formatXAxis"

            i18n-formatCategoryAxisTitle="kendo.chartwizard.formatCategoryAxisTitle|The label of the Title settings of the Category Axis panel."
            [formatCategoryAxisTitle]="messages.formatCategoryAxisTitle"

            i18n-formatCategoryAxisTitlePlaceholder="kendo.chartwizard.formatCategoryAxisTitlePlaceholder|The placeholder of the Title input of the Category Axis panel."
            [formatCategoryAxisTitlePlaceholder]="messages.formatCategoryAxisTitlePlaceholder"

            i18n-formatCategoryAxisTitleFont="kendo.chartwizard.formatCategoryAxisTitleFont|The label of the Font settings of the Title in the Category Axis panel."
            [formatCategoryAxisTitleFont]="messages.formatCategoryAxisTitleFont"

            i18n-formatCategoryAxisTitleFontPlaceholder="kendo.chartwizard.formatCategoryAxisTitleFontPlaceholder|The placeholder of the Font settings of the Title in the Category Axis panel."
            [formatCategoryAxisTitleFontPlaceholder]="messages.formatCategoryAxisTitleFontPlaceholder"

            i18n-formatCategoryAxisTitleSize="kendo.chartwizard.formatCategoryAxisTitleSize|The label of the Size settings of the Title in the Category Axis panel."
            [formatCategoryAxisTitleSize]="messages.formatCategoryAxisTitleSize"

            i18n-formatCategoryAxisTitleSizePlaceholder="kendo.chartwizard.formatCategoryAxisTitleSizePlaceholder|The placeholder of the Size settings of the Title in the Category Axis panel."
            [formatCategoryAxisTitleSizePlaceholder]="messages.formatCategoryAxisTitleSizePlaceholder"

            i18n-formatCategoryAxisTitleColor="kendo.chartwizard.formatCategoryAxisTitleColor|The label of the Color settings of the Title in the Category Axis panel."
            [formatCategoryAxisTitleColor]="messages.formatCategoryAxisTitleColor"

            i18n-formatCategoryAxisLabels="kendo.chartwizard.formatCategoryAxisLabels|The label of the Labels settings of the Category Axis panel."
            [formatCategoryAxisLabels]="messages.formatCategoryAxisLabels"

            i18n-formatCategoryAxisLabelsFont="kendo.chartwizard.formatCategoryAxisLabelsFont|The label of the Font settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsFont]="messages.formatCategoryAxisLabelsFont"

            i18n-formatCategoryAxisLabelsFontPlaceholder="kendo.chartwizard.formatCategoryAxisLabelsFontPlaceholder|The placeholder of the Font settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsFontPlaceholder]="messages.formatCategoryAxisLabelsFontPlaceholder"

            i18n-formatCategoryAxisLabelsSize="kendo.chartwizard.formatCategoryAxisLabelsSize|The label of the Size settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsSize]="messages.formatCategoryAxisLabelsSize"

            i18n-formatCategoryAxisLabelsSizePlaceholder="kendo.chartwizard.formatCategoryAxisLabelsSizePlaceholder|The placeholder of the Size settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsSizePlaceholder]="messages.formatCategoryAxisLabelsSizePlaceholder"

            i18n-formatCategoryAxisLabelsColor="kendo.chartwizard.formatCategoryAxisLabelsColor|The label of the Color settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsColor]="messages.formatCategoryAxisLabelsColor"

            i18n-formatCategoryAxisLabelsRotation="kendo.chartwizard.formatCategoryAxisLabelsRotation|The label of the Rotation settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsRotation]="messages.formatCategoryAxisLabelsRotation"

            i18n-formatCategoryAxisLabelsRotationAuto="kendo.chartwizard.formatCategoryAxisLabelsRotationAuto|The Auto option of the Rotation settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsRotationAuto]="messages.formatCategoryAxisLabelsRotationAuto"

            i18n-formatCategoryAxisLabelsReverseOrder="kendo.chartwizard.formatCategoryAxisLabelsReverseOrder|The label of the Reverse Order checkbox of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsReverseOrder]="messages.formatCategoryAxisLabelsReverseOrder"

            i18n-formatValueAxis="kendo.chartwizard.formatValueAxis|The text of the Value Axis panel of the Format tab."
            [formatValueAxis]="messages.formatValueAxis"

            i18n-formatYAxis="kendo.chartwizard.formatYAxis|The text of the Y Axis panel of the Format tab."
            [formatYAxis]="messages.formatYAxis"

            i18n-formatValueAxisTitle="kendo.chartwizard.formatValueAxisTitle|The label of the Title settings of the Value Axis panel."
            [formatValueAxisTitle]="messages.formatValueAxisTitle"

            i18n-formatValueAxisTitlePlaceholder="kendo.chartwizard.formatValueAxisTitlePlaceholder|The placeholder of the Title settings of the Value Axis panel."
            [formatValueAxisTitlePlaceholder]="messages.formatValueAxisTitlePlaceholder"

            i18n-formatValueAxisTitleFont="kendo.chartwizard.formatValueAxisTitleFont|The label of the Font settings of the Value Axis panel."
            [formatValueAxisTitleFont]="messages.formatValueAxisTitleFont"

            i18n-formatValueAxisTitleFontPlaceholder="kendo.chartwizard.formatValueAxisTitleFontPlaceholder|The placeholder of the Font settings of the Value Axis panel."
            [formatYAxis]="messages.formatValueAxisTitleFontPlaceholder"

            i18n-formatValueAxisTitleSize="kendo.chartwizard.formatValueAxisTitleSize|The label of the Size settings of the Value Axis panel."
            [formatValueAxisTitleSize]="messages.formatValueAxisTitleSize"

            i18n-formatValueAxisTitleSizePlaceholder="kendo.chartwizard.formatValueAxisTitleSizePlaceholder|The placeholder of the Size settings of the Value Axis panel."
            [formatValueAxisTitleSizePlaceholder]="messages.formatValueAxisTitleSizePlaceholder"

            i18n-formatValueAxisTitleColor="kendo.chartwizard.formatValueAxisTitleColor|The label of the Color settings of the Value Axis panel."
            [formatValueAxisTitleColor]="messages.formatValueAxisTitleColor"

            i18n-formatValueAxisLabels="kendo.chartwizard.formatValueAxisLabels|The label of the Labels settings of the Value Axis panel."
            [formatValueAxisLabels]="messages.formatValueAxisLabels"

            i18n-formatValueAxisLabelsFormat="kendo.chartwizard.formatValueAxisLabelsFormat|The label of the Format DropDown of the Labels settings of the Value Axis panel."
            [formatValueAxisLabelsFormat]="messages.formatValueAxisLabelsFormat"

            i18n-formatValueAxisLabelsFormatText="kendo.chartwizard.formatValueAxisLabelsFormatText|The Text option of the Format DropDown of the Labels settings of the Value Axis panel."
            [formatValueAxisLabelsFormatText]="messages.formatValueAxisLabelsFormatText"

            i18n-formatValueAxisLabelsFormatNumber="kendo.chartwizard.formatValueAxisLabelsFormatNumber|The Number option of the Format DropDown of the Labels settings of the Value Axis panel."
            [formatValueAxisLabelsFormatNumber]="messages.formatValueAxisLabelsFormatNumber"

            i18n-formatValueAxisLabelsFormatCurrency="kendo.chartwizard.formatValueAxisLabelsFormatCurrency|The Currency option of the Format DropDown of the Labels settings of the Value Axis panel."
            [formatValueAxisLabelsFormatCurrency]="messages.formatValueAxisLabelsFormatCurrency"

            i18n-formatValueAxisLabelsFormatPercent="kendo.chartwizard.formatValueAxisLabelsFormatPercent|The Percent option of the Format DropDown of the Labels settings of the Value Axis panel."
            [formatValueAxisLabelsFormatPercent]="messages.formatValueAxisLabelsFormatPercent"

            i18n-formatValueAxisLabelsFont="kendo.chartwizard.formatValueAxisLabelsFont|The label of the Font settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsFont]="messages.formatValueAxisLabelsFont"

            i18n-formatValueAxisLabelsFontPlaceholder="kendo.chartwizard.formatValueAxisLabelsFontPlaceholder|The placeholder of the Font settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsFontPlaceholder]="messages.formatValueAxisLabelsFontPlaceholder"

            i18n-formatValueAxisLabelsSize="kendo.chartwizard.formatValueAxisLabelsSize|The label of the Size settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsSize]="messages.formatValueAxisLabelsSize"

            i18n-formatValueAxisLabelsSizePlaceholder="kendo.chartwizard.formatValueAxisLabelsSizePlaceholder|The placeholder of the Size settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsSizePlaceholder]="messages.formatValueAxisLabelsSizePlaceholder"

            i18n-formatValueAxisLabelsColor="kendo.chartwizard.formatValueAxisLabelsColor|The label of the Color settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsColor]="messages.formatValueAxisLabelsColor"

            i18n-formatValueAxisLabelsRotation="kendo.chartwizard.formatValueAxisLabelsRotation|The label of the Rotation settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsRotation]="messages.formatValueAxisLabelsRotation"

            i18n-formatValueAxisLabelsRotationAuto="kendo.chartwizard.formatValueAxisLabelsRotationAuto|The Auto option of the Rotation settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsRotationAuto]="messages.formatValueAxisLabelsRotationAuto"

        ></ng-container>
        <div *ngIf="windowSettings?.modal" @overlayAppear class="k-overlay"> </div>
        <kendo-window
            class="k-chart-wizard"
            [title]="messageFor('windowTitle')"
            [width]="windowWidth"
            [height]="windowHeight"
            [minWidth]="windowSettings?.minWidth"
            [minHeight]="windowSettings?.minHeight"
            [state]="windowSettings?.state"
            [resizable]="true"
            (close)="close.emit()"
        >
            <kendo-splitter class="k-chart-wizard-splitter">
                <kendo-splitter-pane class="k-chart-wizard-preview-pane">
                    <div class="k-preview-pane-header">
                        <kendo-dropdownbutton
                            [svgIcon]="exportIcon"
                            [data]="exportDropdownItems"
                            textField="text"
                            fillMode="flat"
                            (itemClick)="onExport($event)"
                        >
                            {{ messageFor('exportButton') }}
                        </kendo-dropdownbutton>
                    </div>
                    <div class="k-preview-pane-content" [style.height]="'calc(100% - 50px)'">
                        <kendo-chart [transitions]="false" [style.width.%]="100" [style.height.%]="100">
                            <kendo-chart-title
                                [text]="stateService.state.title?.text"
                                [font]="stateService.state.title?.font"
                                [color]="stateService.state.title?.color"
                            ></kendo-chart-title>
                            <kendo-chart-subtitle
                                [text]="stateService.state.subtitle?.text"
                                [font]="stateService.state.subtitle?.font"
                                [color]="stateService.state.subtitle?.color"
                            ></kendo-chart-subtitle>
                            <kendo-chart-area
                                [background]="stateService.state.area?.background"
                                [margin]="stateService.state.area?.margin"
                            >
                            </kendo-chart-area>
                            <kendo-chart-category-axis *ngIf="stateService.state.categoryAxis">
                                <kendo-chart-category-axis-item
                                    *ngFor="let axis of stateService.state.categoryAxis"
                                    [categories]="axis.categories"
                                    [title]="{
                                        text: axis.title?.text,
                                        font: axis.title?.font,
                                        color: axis.title?.color
                                    }"
                                    [labels]="{
                                        rotation: axis.labels?.rotation,
                                        font: axis.labels?.font,
                                        color: axis.labels?.color
                                    }"
                                    [reverse]="axis.reverse"
                                >
                                </kendo-chart-category-axis-item>
                                <kendo-chart-value-axis *ngIf="stateService.state.valueAxis">
                                    <kendo-chart-value-axis-item
                                        *ngFor="let axis of stateService.state.valueAxis"
                                        [title]="{
                                            text: axis.title?.text,
                                            font: axis.title?.font,
                                            color: axis.title?.color
                                        }"
                                        [labels]="{
                                            rotation: axis.labels?.rotation,
                                            font: axis.labels?.font,
                                            color: axis.labels?.color,
                                            format: axis.labels?.format
                                        }"
                                    >
                                    </kendo-chart-value-axis-item>
                                </kendo-chart-value-axis>
                            </kendo-chart-category-axis>
                            <kendo-chart-series>
                                <kendo-chart-series-item
                                    *ngFor="let series of stateService.state.series"
                                    [type]="series.type"
                                    [data]="series.data"
                                    [stack]="series.stack"
                                    [field]="series.field"
                                    [categoryField]="series.categoryField"
                                    [name]="series.name"
                                    [color]="series.color"
                                    [labels]="{ visible: series.labels?.visible }"
                                    [width]="series.width"
                                >
                                </kendo-chart-series-item>
                            </kendo-chart-series>
                            <kendo-chart-legend
                                [visible]="stateService.state.legend?.visible"
                                [position]="stateService.state.legend?.position"
                                [labels]="stateService.state.legend?.labels"
                            >
                            </kendo-chart-legend>
                        </kendo-chart>
                    </div>
                </kendo-splitter-pane>
                <kendo-splitter-pane class="k-chart-wizard-property-pane" [collapsible]="true" [collapsed]="collapsedConfigurationPane" [size]="stateService.splitterPaneSize">
                    <kendo-tabstrip [keepTabContent]="true">
                        <kendo-tabstrip-tab [title]="messageFor('tabChart')" [selected]="true">
                            <ng-template kendoTabContent>
                                <kendo-chartwizard-property-pane-chart-tab>
                                </kendo-chartwizard-property-pane-chart-tab>
                            </ng-template>
                        </kendo-tabstrip-tab>
                        <kendo-tabstrip-tab [title]="messageFor('tabData')">
                            <ng-template kendoTabContent>
                                <kendo-chartwizard-property-pane-data-tab> </kendo-chartwizard-property-pane-data-tab>
                            </ng-template>
                        </kendo-tabstrip-tab>
                        <kendo-tabstrip-tab [title]="messageFor('tabFormat')">
                            <ng-template kendoTabContent>
                                <kendo-chartwizard-property-pane-format-tab>
                                </kendo-chartwizard-property-pane-format-tab>
                            </ng-template>
                        </kendo-tabstrip-tab>
                    </kendo-tabstrip>
                </kendo-splitter-pane>
            </kendo-splitter>
            <div kendoWatermarkOverlay *ngIf="showLicenseWatermark"></div>
        </kendo-window>
    `, isInline: true, dependencies: [{ kind: "component", type: WindowComponent, selector: "kendo-window", inputs: ["autoFocusedElement", "title", "draggable", "resizable", "themeColor", "keepContent", "state", "minWidth", "minHeight", "width", "height", "top", "left"], outputs: ["dragStart", "dragEnd", "resizeStart", "resizeEnd", "close", "widthChange", "heightChange", "topChange", "leftChange", "stateChange"], exportAs: ["kendoWindow"] }, { kind: "component", type: SplitterComponent, selector: "kendo-splitter", inputs: ["orientation", "splitbarWidth", "resizeStep", "splitterBarClass"], outputs: ["layoutChange"], exportAs: ["kendoSplitter"] }, { kind: "component", type: SplitterPaneComponent, selector: "kendo-splitter-pane", inputs: ["order", "size", "splitterBarAttributes", "splitterBarClass", "min", "max", "resizable", "collapsible", "scrollable", "collapsed", "orientation", "containsSplitter", "overlayContent"], outputs: ["sizeChange", "collapsedChange"], exportAs: ["kendoSplitterPane"] }, { kind: "component", type: DropDownButtonComponent, selector: "kendo-dropdownbutton", inputs: ["arrowIcon", "icon", "svgIcon", "iconClass", "imageUrl", "textField", "data", "size", "rounded", "fillMode", "themeColor", "buttonAttributes"], outputs: ["itemClick", "focus", "blur"], exportAs: ["kendoDropDownButton"] }, { kind: "component", type: ChartComponent, selector: "kendo-chart", inputs: ["pannable", "renderAs", "seriesColors", "subtitle", "title", "noData", "transitions", "zoomable", "axisDefaults", "categoryAxis", "chartArea", "legend", "panes", "paneDefaults", "plotArea", "series", "seriesDefaults", "tooltip", "valueAxis", "xAxis", "yAxis", "resizeRateLimit", "popupSettings", "drilldownLevel"], outputs: ["axisLabelClick", "drag", "dragEnd", "dragStart", "legendItemHover", "legendItemLeave", "noteClick", "noteHover", "noteLeave", "paneRender", "plotAreaClick", "plotAreaHover", "plotAreaLeave", "render", "select", "selectEnd", "selectStart", "seriesClick", "drilldown", "seriesHover", "seriesOver", "seriesLeave", "zoom", "zoomEnd", "zoomStart", "legendItemClick", "drilldownLevelChange"], exportAs: ["kendoChart"] }, { kind: "component", type: TitleComponent, selector: "kendo-chart-title", inputs: ["align", "background", "border", "color", "font", "margin", "padding", "position", "text", "description", "visible"] }, { kind: "component", type: SubtitleComponent, selector: "kendo-chart-subtitle", inputs: ["align", "background", "border", "color", "font", "margin", "padding", "position", "text", "visible"] }, { kind: "component", type: ChartAreaComponent, selector: "kendo-chart-area", inputs: ["background", "border", "height", "margin", "opacity", "width"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: CategoryAxisComponent, selector: "kendo-chart-category-axis" }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: CategoryAxisItemComponent, selector: "kendo-chart-category-axis-item", inputs: ["autoBaseUnitSteps", "axisCrossingValue", "background", "baseUnit", "baseUnitStep", "categories", "color", "justified", "line", "majorGridLines", "majorTicks", "max", "maxDateGroups", "maxDivisions", "min", "minorGridLines", "minorTicks", "name", "pane", "plotBands", "reverse", "roundToBaseUnit", "startAngle", "type", "visible", "weekStartDay", "crosshair", "labels", "notes", "select", "title", "rangeLabels"] }, { kind: "component", type: ValueAxisComponent, selector: "kendo-chart-value-axis" }, { kind: "component", type: ValueAxisItemComponent, selector: "kendo-chart-value-axis-item", inputs: ["axisCrossingValue", "background", "color", "line", "majorGridLines", "majorTicks", "majorUnit", "max", "min", "minorGridLines", "minorTicks", "minorUnit", "name", "narrowRange", "pane", "plotBands", "reverse", "type", "visible", "crosshair", "labels", "notes", "title"] }, { kind: "component", type: SeriesComponent, selector: "kendo-chart-series" }, { kind: "component", type: SeriesItemComponent, selector: "kendo-chart-series-item", inputs: ["aggregate", "autoFit", "axis", "border", "categoryAxis", "categoryField", "closeField", "color", "colorField", "connectors", "currentField", "dashType", "data", "downColor", "downColorField", "drilldownField", "dynamicHeight", "dynamicSlope", "errorHighField", "errorLowField", "explodeField", "field", "fromField", "gap", "highField", "holeSize", "line", "lowField", "lowerField", "margin", "maxSize", "mean", "meanField", "median", "medianField", "minSize", "missingValues", "name", "neckRatio", "negativeColor", "negativeValues", "noteTextField", "opacity", "openField", "outliersField", "overlay", "padding", "q1Field", "q3Field", "segmentSpacing", "size", "sizeField", "spacing", "stack", "startAngle", "style", "summaryField", "target", "toField", "type", "upperField", "visible", "visibleInLegend", "visibleInLegendField", "visual", "width", "whiskers", "xAxis", "xErrorHighField", "xErrorLowField", "xField", "yAxis", "yErrorHighField", "yErrorLowField", "yField", "zIndex", "trendline", "for", "legendItem", "pattern", "patternField", "errorBars", "extremes", "highlight", "labels", "markers", "notes", "outliers", "tooltip"] }, { kind: "component", type: LegendComponent, selector: "kendo-chart-legend", inputs: ["align", "background", "border", "height", "labels", "margin", "offsetX", "offsetY", "orientation", "padding", "position", "reverse", "visible", "width", "markers", "spacing", "inactiveItems", "item", "title", "focusHighlight"] }, { kind: "component", type: TabStripComponent, selector: "kendo-tabstrip", inputs: ["height", "animate", "tabAlignment", "tabPosition", "keepTabContent", "closable", "scrollable", "size", "closeIcon", "closeIconClass", "closeSVGIcon", "showContentArea"], outputs: ["tabSelect", "tabClose", "tabScroll"], exportAs: ["kendoTabStrip"] }, { kind: "component", type: TabStripTabComponent, selector: "kendo-tabstrip-tab", inputs: ["title", "disabled", "cssClass", "cssStyle", "selected", "closable", "closeIcon", "closeIconClass", "closeSVGIcon"], exportAs: ["kendoTabStripTab"] }, { kind: "directive", type: TabContentDirective, selector: "[kendoTabContent]" }, { kind: "component", type: ChartWizardPropertyPaneChartTabComponent, selector: "kendo-chartwizard-property-pane-chart-tab" }, { kind: "component", type: ChartWizardPropertyPaneFormatTabComponent, selector: "kendo-chartwizard-property-pane-format-tab" }, { kind: "component", type: ChartWizardPropertyPaneDataTabComponent, selector: "kendo-chartwizard-property-pane-data-tab" }, { kind: "component", type: WatermarkOverlayComponent, selector: "div[kendoWatermarkOverlay]" }, { kind: "directive", type: LocalizedMessagesDirective, selector: "[kendoChartWizardLocalizedMessages]" }], animations: [
            trigger('overlayAppear', [
                state('in', style({ opacity: 1 })),
                transition('void => *', [style({ opacity: 0.1 }), animate('.3s cubic-bezier(.2, .6, .4, 1)')])
            ])
        ], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardComponent, decorators: [{
            type: Component,
            args: [{
                    animations: [
                        trigger('overlayAppear', [
                            state('in', style({ opacity: 1 })),
                            transition('void => *', [style({ opacity: 0.1 }), animate('.3s cubic-bezier(.2, .6, .4, 1)')])
                        ])
                    ],
                    changeDetection: ChangeDetectionStrategy.OnPush,
                    exportAs: 'kendoChartWizard',
                    providers: [
                        LocalizationService,
                        {
                            provide: L10N_PREFIX,
                            useValue: 'kendo.chartwizard',
                        },
                        ChartWizardLocalizationService,
                        {
                            provide: LocalizationService,
                            useExisting: ChartWizardLocalizationService
                        },
                        StateService
                    ],
                    selector: 'kendo-chartwizard',
                    template: `
        <ng-container
            kendoChartWizardLocalizedMessages

            i18n-windowTitle="kendo.chartwizard.windowTitle|The title of the window."
            [windowTitle]="messages.windowTitle"

            i18n-exportButton="kendo.chartwizard.exportButton|The text of the Export DropDownButton."
            [exportButton]="messages.exportButton"

            i18n-exportPDFButton="kendo.chartwizard.exportPDFButton|The text of the Export DropDownButton option that represents PDF."
            [exportPDFButton]="messages.exportPDFButton"

            i18n-exportSVGButton="kendo.chartwizard.exportSVGButton|The text of the Export DropDownButton option that represents SVG."
            [exportSVGButton]="messages.exportSVGButton"

            i18n-exportPNGButton="kendo.chartwizard.exportPNGButton|The text of the Export DropDownButton option that represents PNG."
            [exportPNGButton]="messages.exportPNGButton"

            i18n-tabChart="kendo.chartwizard.tabChart|The text of the Chart tab of the property pane."
            [tabChart]="messages.tabChart"

            i18n-tabData="kendo.chartwizard.tabData|The text of the Data tab of the property pane."
            [tabData]="messages.tabData"

            i18n-tabFormat="kendo.chartwizard.tabFormat|The text of the Format tab of the property pane."
            [tabFormat]="messages.tabFormat"

            i18n-barChart="kendo.chartwizard.barChart|The text of the Chart panel that represents Bar Charts."
            [barChart]="messages.barChart"

            i18n-barChartBar="kendo.chartwizard.barChartBar|The text of the Bar Chart type."
            [barChartBar]="messages.barChartBar"

            i18n-barChartStackedBar="kendo.chartwizard.barChartStackedBar|The text of the Stacked Bar Chart type."
            [barChartStackedBar]="messages.barChartStackedBar"

            i18n-barChart100StackedBar="kendo.chartwizard.barChart100StackedBar|The text of the 100% Stacked Bar Chart type."
            [barChart100StackedBar]="messages.barChart100StackedBar"

            i18n-pieChart="kendo.chartwizard.pieChart|The text of the Chart panel that represents Pie Charts."
            [pieChart]="messages.pieChart"

            i18n-pieChartPie="kendo.chartwizard.pieChartPie|The text of the Pie Chart type."
            [pieChartPie]="messages.pieChartPie"

            i18n-columnChart="kendo.chartwizard.columnChart|The text of the Chart panel that represents Column Charts."
            [columnChart]="messages.columnChart"

            i18n-columnChartColumn="kendo.chartwizard.columnChartColumn|The text of the Column Chart type."
            [columnChartColumn]="messages.columnChartColumn"

            i18n-columnChartStackedColumn="kendo.chartwizard.columnChartStackedColumn|The text of the Stacked Column Chart type."
            [columnChartStackedColumn]="messages.columnChartStackedColumn"

            i18n-columnChart100StackedColumn="kendo.chartwizard.columnChart100StackedColumn|The text of the 100% Stacked Column Chart type."
            [columnChart100StackedColumn]="messages.columnChart100StackedColumn"

            i18n-lineChart="kendo.chartwizard.lineChart|The text of the Chart panel that represents Line Charts."
            [lineChart]="messages.lineChart"

            i18n-lineChartLine="kendo.chartwizard.lineChartLine|The text of the Line Chart type."
            [lineChartLine]="messages.lineChartLine"

            i18n-lineChartStackedLine="kendo.chartwizard.lineChartStackedLine|The text of the Stacked Line Chart type."
            [lineChartStackedLine]="messages.lineChartStackedLine"

            i18n-lineChart100StackedLine="kendo.chartwizard.lineChart100StackedLine|The text of the 100% Stacked Line Chart type."
            [lineChart100StackedLine]="messages.lineChart100StackedLine"

            i18n-scatterChart="kendo.chartwizard.scatterChart|The text of the Chart panel that represents Scatter Charts."
            [scatterChart]="messages.scatterChart"

            i18n-scatterChartScatter="kendo.chartwizard.scatterChartScatter|The text of the Scatter Chart type."
            [scatterChartScatter]="messages.scatterChartScatter"

            i18n-configuration="kendo.chartwizard.configuration|The text of the Configuration panel of the Data tab."
            [configuration]="messages.configuration"

            i18n-configurationCategoryAxis="kendo.chartwizard.configurationCategoryAxis|The caption of the Category Axis DropDown in the Configuration panel."
            [configurationCategoryAxis]="messages.configurationCategoryAxis"

            i18n-configurationXAxis="kendo.chartwizard.configurationXAxis|The caption of the X Axis DropDown in the Configuration panel when a Scatter Chart is selected."
            [configurationXAxis]="messages.configurationXAxis"

            i18n-configurationValueAxis="kendo.chartwizard.configurationValueAxis|The caption of the Value Axis DropDown in the Configuration panel when a Pie Chart is selected."
            [configurationValueAxis]="messages.configurationValueAxis"

            i18n-configurationSeries="kendo.chartwizard.configurationSeries|The text of the Series Grid in the Configuration panel when a Categorical Chart is selected."
            [configurationSeries]="messages.configurationSeries"

            i18n-configurationSeriesAdd="kendo.chartwizard.configurationSeriesAdd|The text of the Add Series button in the Grid of the Configuration panel."
            [configurationSeriesAdd]="messages.configurationSeriesAdd"

            i18n-formatChartArea="kendo.chartwizard.formatChartArea|The text of the Chart Area panel of the Format tab."
            [formatChartArea]="messages.formatChartArea"

            i18n-formatChartAreaMargins="kendo.chartwizard.formatChartAreaMargins|The text of the Margins settings of the Chart Area panel."
            [formatChartAreaMargins]="messages.formatChartAreaMargins"

            i18n-formatChartAreaMarginsAuto="kendo.chartwizard.formatChartAreaMarginsAuto|The placeholder of the Margins settings of the Chart Area panel."
            [formatChartAreaMarginsAuto]="messages.formatChartAreaMarginsAuto"

            i18n-formatChartAreaMarginsLeft="kendo.chartwizard.formatChartAreaMarginsLeft|The label of the Left margin setting of the Chart Area panel."
            [formatChartAreaMarginsLeft]="messages.formatChartAreaMarginsLeft"

            i18n-formatChartAreaMarginsRight="kendo.chartwizard.formatChartAreaMarginsRight|The label of the Right margin setting of the Chart Area panel."
            [formatChartAreaMarginsRight]="messages.formatChartAreaMarginsRight"

            i18n-formatChartAreaMarginsTop="kendo.chartwizard.formatChartAreaMarginsTop|The label of the Top margin setting of the Chart Area panel."
            [formatChartAreaMarginsTop]="messages.formatChartAreaMarginsTop"

            i18n-formatChartAreaMarginsBottom="kendo.chartwizard.formatChartAreaMarginsBottom|The label of the Bottom margin setting of the Chart Area panel."
            [formatChartAreaMarginsBottom]="messages.formatChartAreaMarginsBottom"

            i18n-formatChartAreaBackground="kendo.chartwizard.formatChartAreaBackground|The text of the Background settings of the Chart Area panel."
            [formatChartAreaBackground]="messages.formatChartAreaBackground"

            i18n-formatChartAreaBackgroundColor="kendo.chartwizard.formatChartAreaBackgroundColor|The label of the Color background setting of the Chart Area panel."
            [formatChartAreaBackgroundColor]="messages.formatChartAreaBackgroundColor"

            i18n-formatTitle="kendo.chartwizard.formatTitle|The text of the Title panel of the Format tab."
            [formatTitle]="messages.formatTitle"

            i18n-formatTitleApplyTo="kendo.chartwizard.formatTitleApplyTo|The label of the Apply to DropDown of the Title panel."
            [formatTitleApplyTo]="messages.formatTitleApplyTo"

            i18n-formatTitleChartTitle="kendo.chartwizard.formatTitleChartTitle|The text of the Chart Title option of the Apply to DropDown in the Title panel."
            [formatTitleChartTitle]="messages.formatTitleChartTitle"

            i18n-formatTitleChartSubtitle="kendo.chartwizard.formatTitleChartSubtitle|The text of the Chart Subtitle option of the Apply to DropDown in the Title panel."
            [formatTitleChartSubtitle]="messages.formatTitleChartSubtitle"

            i18n-formatTitleLabel="kendo.chartwizard.formatTitleLabel|The label of the Title input of the Title panel."
            [formatTitleLabel]="messages.formatTitleLabel"

            i18n-formatTitleFont="kendo.chartwizard.formatTitleFont|The label of the Font setting of the Title panel."
            [formatTitleFont]="messages.formatTitleFont"

            i18n-formatTitleFontPlaceholder="kendo.chartwizard.formatTitleFontPlaceholder|The placeholder of the Font setting of the Title panel."
            [formatTitleFontPlaceholder]="messages.formatTitleFontPlaceholder"

            i18n-formatTitleSize="kendo.chartwizard.formatTitleSize|The label of the Size setting of the Title panel."
            [formatTitleSize]="messages.formatTitleSize"

            i18n-formatTitleSizePlaceholder="kendo.chartwizard.formatTitleSizePlaceholder|The placeholder of the Size setting of the Title panel."
            [formatTitleSizePlaceholder]="messages.formatTitleSizePlaceholder"

            i18n-formatTitleColor="kendo.chartwizard.formatTitleColor|The label of the Color setting of the Title panel."
            [formatTitleColor]="messages.formatTitleColor"

            i18n-formatSeries="kendo.chartwizard.formatSeries|The text of the Series panel of the Format tab."
            [formatSeries]="messages.formatSeries"

            i18n-formatSeriesApplyTo="kendo.chartwizard.formatSeriesApplyTo|The label of the Apply to DropDown of the Series panel."
            [formatSeriesApplyTo]="messages.formatSeriesApplyTo"

            i18n-formatSeriesAllSeries="kendo.chartwizard.formatSeriesAllSeries|The text of the All Series option of the Apply to DropDown in the Series panel."
            [formatSeriesAllSeries]="messages.formatSeriesAllSeries"

            i18n-formatSeriesColor="kendo.chartwizard.formatSeriesColor|The label of the Color setting of the Series panel."
            [formatSeriesColor]="messages.formatSeriesColor"

            i18n-formatSeriesShowLabels="kendo.chartwizard.formatSeriesShowLabels|The label of the Show Labels checkbox of the Series panel."
            [formatSeriesShowLabels]="messages.formatSeriesShowLabels"

            i18n-formatLegend="kendo.chartwizard.formatLegend|The text of the Legend panel of the Format tab."
            [formatLegend]="messages.formatLegend"

            i18n-formatLegendShowLegend="kendo.chartwizard.formatLegendShowLegend|The label of the Show Legend switch of the Legend panel."
            [formatLegendShowLegend]="messages.formatLegendShowLegend"

            i18n-formatLegendFont="kendo.chartwizard.formatLegendFont|The label of the Font setting of the Legend panel."
            [formatLegendFont]="messages.formatLegendFont"

            i18n-formatLegendFontPlaceholder="kendo.chartwizard.formatLegendFontPlaceholder|The placeholder of the Font setting of the Legend panel."
            [formatLegendFontPlaceholder]="messages.formatLegendFontPlaceholder"

            i18n-formatLegendSize="kendo.chartwizard.formatLegendSize|The label of the Size setting of the Legend panel."
            [formatLegendSize]="messages.formatLegendSize"

            i18n-formatLegendSizePlaceholder="kendo.chartwizard.formatLegendSizePlaceholder|The placeholder of the Size setting of the Legend panel."
            [formatLegendSizePlaceholder]="messages.formatLegendSizePlaceholder"

            i18n-formatLegendColor="kendo.chartwizard.formatLegendColor|The label of the Color setting of the Legend panel."
            [formatLegendColor]="messages.formatLegendColor"

            i18n-formatLegendPosition="kendo.chartwizard.formatLegendPosition|The label of the Posiiton DropDown of the Legend panel."
            [formatLegendPosition]="messages.formatLegendPosition"

            i18n-formatLegendPositionTop="kendo.chartwizard.formatLegendPositionTop|The text of the Top option of the Position DropDown of the Legend panel."
            [formatLegendPositionTop]="messages.formatLegendPositionTop"

            i18n-formatLegendPositionBottom="kendo.chartwizard.formatLegendPositionBottom|The text of the Bottom option of the Position DropDown of the Legend panel."
            [formatLegendPositionBottom]="messages.formatLegendPositionBottom"

            i18n-formatLegendPositionLeft="kendo.chartwizard.formatLegendPositionLeft|The text of the Left option of the Position DropDown of the Legend panel."
            [formatLegendPositionLeft]="messages.formatLegendPositionLeft"

            i18n-formatLegendPositionRight="kendo.chartwizard.formatLegendPositionRight|The text of the Right option of the Position DropDown of the Legend panel."
            [formatLegendPositionRight]="messages.formatLegendPositionRight"

            i18n-formatCategoryAxis="kendo.chartwizard.formatCategoryAxis|The text of the Category Axis panel of the Format tab."
            [formatCategoryAxis]="messages.formatCategoryAxis"

            i18n-formatXAxis="kendo.chartwizard.formatXAxis|The text of the X Axis panel of the Format tab when a Scatter Chart is selected."
            [formatXAxis]="messages.formatXAxis"

            i18n-formatCategoryAxisTitle="kendo.chartwizard.formatCategoryAxisTitle|The label of the Title settings of the Category Axis panel."
            [formatCategoryAxisTitle]="messages.formatCategoryAxisTitle"

            i18n-formatCategoryAxisTitlePlaceholder="kendo.chartwizard.formatCategoryAxisTitlePlaceholder|The placeholder of the Title input of the Category Axis panel."
            [formatCategoryAxisTitlePlaceholder]="messages.formatCategoryAxisTitlePlaceholder"

            i18n-formatCategoryAxisTitleFont="kendo.chartwizard.formatCategoryAxisTitleFont|The label of the Font settings of the Title in the Category Axis panel."
            [formatCategoryAxisTitleFont]="messages.formatCategoryAxisTitleFont"

            i18n-formatCategoryAxisTitleFontPlaceholder="kendo.chartwizard.formatCategoryAxisTitleFontPlaceholder|The placeholder of the Font settings of the Title in the Category Axis panel."
            [formatCategoryAxisTitleFontPlaceholder]="messages.formatCategoryAxisTitleFontPlaceholder"

            i18n-formatCategoryAxisTitleSize="kendo.chartwizard.formatCategoryAxisTitleSize|The label of the Size settings of the Title in the Category Axis panel."
            [formatCategoryAxisTitleSize]="messages.formatCategoryAxisTitleSize"

            i18n-formatCategoryAxisTitleSizePlaceholder="kendo.chartwizard.formatCategoryAxisTitleSizePlaceholder|The placeholder of the Size settings of the Title in the Category Axis panel."
            [formatCategoryAxisTitleSizePlaceholder]="messages.formatCategoryAxisTitleSizePlaceholder"

            i18n-formatCategoryAxisTitleColor="kendo.chartwizard.formatCategoryAxisTitleColor|The label of the Color settings of the Title in the Category Axis panel."
            [formatCategoryAxisTitleColor]="messages.formatCategoryAxisTitleColor"

            i18n-formatCategoryAxisLabels="kendo.chartwizard.formatCategoryAxisLabels|The label of the Labels settings of the Category Axis panel."
            [formatCategoryAxisLabels]="messages.formatCategoryAxisLabels"

            i18n-formatCategoryAxisLabelsFont="kendo.chartwizard.formatCategoryAxisLabelsFont|The label of the Font settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsFont]="messages.formatCategoryAxisLabelsFont"

            i18n-formatCategoryAxisLabelsFontPlaceholder="kendo.chartwizard.formatCategoryAxisLabelsFontPlaceholder|The placeholder of the Font settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsFontPlaceholder]="messages.formatCategoryAxisLabelsFontPlaceholder"

            i18n-formatCategoryAxisLabelsSize="kendo.chartwizard.formatCategoryAxisLabelsSize|The label of the Size settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsSize]="messages.formatCategoryAxisLabelsSize"

            i18n-formatCategoryAxisLabelsSizePlaceholder="kendo.chartwizard.formatCategoryAxisLabelsSizePlaceholder|The placeholder of the Size settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsSizePlaceholder]="messages.formatCategoryAxisLabelsSizePlaceholder"

            i18n-formatCategoryAxisLabelsColor="kendo.chartwizard.formatCategoryAxisLabelsColor|The label of the Color settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsColor]="messages.formatCategoryAxisLabelsColor"

            i18n-formatCategoryAxisLabelsRotation="kendo.chartwizard.formatCategoryAxisLabelsRotation|The label of the Rotation settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsRotation]="messages.formatCategoryAxisLabelsRotation"

            i18n-formatCategoryAxisLabelsRotationAuto="kendo.chartwizard.formatCategoryAxisLabelsRotationAuto|The Auto option of the Rotation settings of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsRotationAuto]="messages.formatCategoryAxisLabelsRotationAuto"

            i18n-formatCategoryAxisLabelsReverseOrder="kendo.chartwizard.formatCategoryAxisLabelsReverseOrder|The label of the Reverse Order checkbox of the Labels in the Category Axis panel."
            [formatCategoryAxisLabelsReverseOrder]="messages.formatCategoryAxisLabelsReverseOrder"

            i18n-formatValueAxis="kendo.chartwizard.formatValueAxis|The text of the Value Axis panel of the Format tab."
            [formatValueAxis]="messages.formatValueAxis"

            i18n-formatYAxis="kendo.chartwizard.formatYAxis|The text of the Y Axis panel of the Format tab."
            [formatYAxis]="messages.formatYAxis"

            i18n-formatValueAxisTitle="kendo.chartwizard.formatValueAxisTitle|The label of the Title settings of the Value Axis panel."
            [formatValueAxisTitle]="messages.formatValueAxisTitle"

            i18n-formatValueAxisTitlePlaceholder="kendo.chartwizard.formatValueAxisTitlePlaceholder|The placeholder of the Title settings of the Value Axis panel."
            [formatValueAxisTitlePlaceholder]="messages.formatValueAxisTitlePlaceholder"

            i18n-formatValueAxisTitleFont="kendo.chartwizard.formatValueAxisTitleFont|The label of the Font settings of the Value Axis panel."
            [formatValueAxisTitleFont]="messages.formatValueAxisTitleFont"

            i18n-formatValueAxisTitleFontPlaceholder="kendo.chartwizard.formatValueAxisTitleFontPlaceholder|The placeholder of the Font settings of the Value Axis panel."
            [formatYAxis]="messages.formatValueAxisTitleFontPlaceholder"

            i18n-formatValueAxisTitleSize="kendo.chartwizard.formatValueAxisTitleSize|The label of the Size settings of the Value Axis panel."
            [formatValueAxisTitleSize]="messages.formatValueAxisTitleSize"

            i18n-formatValueAxisTitleSizePlaceholder="kendo.chartwizard.formatValueAxisTitleSizePlaceholder|The placeholder of the Size settings of the Value Axis panel."
            [formatValueAxisTitleSizePlaceholder]="messages.formatValueAxisTitleSizePlaceholder"

            i18n-formatValueAxisTitleColor="kendo.chartwizard.formatValueAxisTitleColor|The label of the Color settings of the Value Axis panel."
            [formatValueAxisTitleColor]="messages.formatValueAxisTitleColor"

            i18n-formatValueAxisLabels="kendo.chartwizard.formatValueAxisLabels|The label of the Labels settings of the Value Axis panel."
            [formatValueAxisLabels]="messages.formatValueAxisLabels"

            i18n-formatValueAxisLabelsFormat="kendo.chartwizard.formatValueAxisLabelsFormat|The label of the Format DropDown of the Labels settings of the Value Axis panel."
            [formatValueAxisLabelsFormat]="messages.formatValueAxisLabelsFormat"

            i18n-formatValueAxisLabelsFormatText="kendo.chartwizard.formatValueAxisLabelsFormatText|The Text option of the Format DropDown of the Labels settings of the Value Axis panel."
            [formatValueAxisLabelsFormatText]="messages.formatValueAxisLabelsFormatText"

            i18n-formatValueAxisLabelsFormatNumber="kendo.chartwizard.formatValueAxisLabelsFormatNumber|The Number option of the Format DropDown of the Labels settings of the Value Axis panel."
            [formatValueAxisLabelsFormatNumber]="messages.formatValueAxisLabelsFormatNumber"

            i18n-formatValueAxisLabelsFormatCurrency="kendo.chartwizard.formatValueAxisLabelsFormatCurrency|The Currency option of the Format DropDown of the Labels settings of the Value Axis panel."
            [formatValueAxisLabelsFormatCurrency]="messages.formatValueAxisLabelsFormatCurrency"

            i18n-formatValueAxisLabelsFormatPercent="kendo.chartwizard.formatValueAxisLabelsFormatPercent|The Percent option of the Format DropDown of the Labels settings of the Value Axis panel."
            [formatValueAxisLabelsFormatPercent]="messages.formatValueAxisLabelsFormatPercent"

            i18n-formatValueAxisLabelsFont="kendo.chartwizard.formatValueAxisLabelsFont|The label of the Font settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsFont]="messages.formatValueAxisLabelsFont"

            i18n-formatValueAxisLabelsFontPlaceholder="kendo.chartwizard.formatValueAxisLabelsFontPlaceholder|The placeholder of the Font settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsFontPlaceholder]="messages.formatValueAxisLabelsFontPlaceholder"

            i18n-formatValueAxisLabelsSize="kendo.chartwizard.formatValueAxisLabelsSize|The label of the Size settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsSize]="messages.formatValueAxisLabelsSize"

            i18n-formatValueAxisLabelsSizePlaceholder="kendo.chartwizard.formatValueAxisLabelsSizePlaceholder|The placeholder of the Size settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsSizePlaceholder]="messages.formatValueAxisLabelsSizePlaceholder"

            i18n-formatValueAxisLabelsColor="kendo.chartwizard.formatValueAxisLabelsColor|The label of the Color settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsColor]="messages.formatValueAxisLabelsColor"

            i18n-formatValueAxisLabelsRotation="kendo.chartwizard.formatValueAxisLabelsRotation|The label of the Rotation settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsRotation]="messages.formatValueAxisLabelsRotation"

            i18n-formatValueAxisLabelsRotationAuto="kendo.chartwizard.formatValueAxisLabelsRotationAuto|The Auto option of the Rotation settings of the Labels in the Value Axis panel."
            [formatValueAxisLabelsRotationAuto]="messages.formatValueAxisLabelsRotationAuto"

        ></ng-container>
        <div *ngIf="windowSettings?.modal" @overlayAppear class="k-overlay"> </div>
        <kendo-window
            class="k-chart-wizard"
            [title]="messageFor('windowTitle')"
            [width]="windowWidth"
            [height]="windowHeight"
            [minWidth]="windowSettings?.minWidth"
            [minHeight]="windowSettings?.minHeight"
            [state]="windowSettings?.state"
            [resizable]="true"
            (close)="close.emit()"
        >
            <kendo-splitter class="k-chart-wizard-splitter">
                <kendo-splitter-pane class="k-chart-wizard-preview-pane">
                    <div class="k-preview-pane-header">
                        <kendo-dropdownbutton
                            [svgIcon]="exportIcon"
                            [data]="exportDropdownItems"
                            textField="text"
                            fillMode="flat"
                            (itemClick)="onExport($event)"
                        >
                            {{ messageFor('exportButton') }}
                        </kendo-dropdownbutton>
                    </div>
                    <div class="k-preview-pane-content" [style.height]="'calc(100% - 50px)'">
                        <kendo-chart [transitions]="false" [style.width.%]="100" [style.height.%]="100">
                            <kendo-chart-title
                                [text]="stateService.state.title?.text"
                                [font]="stateService.state.title?.font"
                                [color]="stateService.state.title?.color"
                            ></kendo-chart-title>
                            <kendo-chart-subtitle
                                [text]="stateService.state.subtitle?.text"
                                [font]="stateService.state.subtitle?.font"
                                [color]="stateService.state.subtitle?.color"
                            ></kendo-chart-subtitle>
                            <kendo-chart-area
                                [background]="stateService.state.area?.background"
                                [margin]="stateService.state.area?.margin"
                            >
                            </kendo-chart-area>
                            <kendo-chart-category-axis *ngIf="stateService.state.categoryAxis">
                                <kendo-chart-category-axis-item
                                    *ngFor="let axis of stateService.state.categoryAxis"
                                    [categories]="axis.categories"
                                    [title]="{
                                        text: axis.title?.text,
                                        font: axis.title?.font,
                                        color: axis.title?.color
                                    }"
                                    [labels]="{
                                        rotation: axis.labels?.rotation,
                                        font: axis.labels?.font,
                                        color: axis.labels?.color
                                    }"
                                    [reverse]="axis.reverse"
                                >
                                </kendo-chart-category-axis-item>
                                <kendo-chart-value-axis *ngIf="stateService.state.valueAxis">
                                    <kendo-chart-value-axis-item
                                        *ngFor="let axis of stateService.state.valueAxis"
                                        [title]="{
                                            text: axis.title?.text,
                                            font: axis.title?.font,
                                            color: axis.title?.color
                                        }"
                                        [labels]="{
                                            rotation: axis.labels?.rotation,
                                            font: axis.labels?.font,
                                            color: axis.labels?.color,
                                            format: axis.labels?.format
                                        }"
                                    >
                                    </kendo-chart-value-axis-item>
                                </kendo-chart-value-axis>
                            </kendo-chart-category-axis>
                            <kendo-chart-series>
                                <kendo-chart-series-item
                                    *ngFor="let series of stateService.state.series"
                                    [type]="series.type"
                                    [data]="series.data"
                                    [stack]="series.stack"
                                    [field]="series.field"
                                    [categoryField]="series.categoryField"
                                    [name]="series.name"
                                    [color]="series.color"
                                    [labels]="{ visible: series.labels?.visible }"
                                    [width]="series.width"
                                >
                                </kendo-chart-series-item>
                            </kendo-chart-series>
                            <kendo-chart-legend
                                [visible]="stateService.state.legend?.visible"
                                [position]="stateService.state.legend?.position"
                                [labels]="stateService.state.legend?.labels"
                            >
                            </kendo-chart-legend>
                        </kendo-chart>
                    </div>
                </kendo-splitter-pane>
                <kendo-splitter-pane class="k-chart-wizard-property-pane" [collapsible]="true" [collapsed]="collapsedConfigurationPane" [size]="stateService.splitterPaneSize">
                    <kendo-tabstrip [keepTabContent]="true">
                        <kendo-tabstrip-tab [title]="messageFor('tabChart')" [selected]="true">
                            <ng-template kendoTabContent>
                                <kendo-chartwizard-property-pane-chart-tab>
                                </kendo-chartwizard-property-pane-chart-tab>
                            </ng-template>
                        </kendo-tabstrip-tab>
                        <kendo-tabstrip-tab [title]="messageFor('tabData')">
                            <ng-template kendoTabContent>
                                <kendo-chartwizard-property-pane-data-tab> </kendo-chartwizard-property-pane-data-tab>
                            </ng-template>
                        </kendo-tabstrip-tab>
                        <kendo-tabstrip-tab [title]="messageFor('tabFormat')">
                            <ng-template kendoTabContent>
                                <kendo-chartwizard-property-pane-format-tab>
                                </kendo-chartwizard-property-pane-format-tab>
                            </ng-template>
                        </kendo-tabstrip-tab>
                    </kendo-tabstrip>
                </kendo-splitter-pane>
            </kendo-splitter>
            <div kendoWatermarkOverlay *ngIf="showLicenseWatermark"></div>
        </kendo-window>
    `,
                    standalone: true,
                    imports: [
                        WindowComponent,
                        SplitterComponent,
                        SplitterPaneComponent,
                        DropDownButtonComponent,
                        ChartComponent,
                        TitleComponent,
                        SubtitleComponent,
                        ChartAreaComponent,
                        NgIf,
                        CategoryAxisComponent,
                        NgFor,
                        CategoryAxisItemComponent,
                        ValueAxisComponent,
                        ValueAxisItemComponent,
                        SeriesComponent,
                        SeriesItemComponent,
                        XAxisComponent,
                        XAxisItemComponent,
                        YAxisComponent,
                        YAxisItemComponent,
                        LegendComponent,
                        TabStripComponent,
                        TabStripTabComponent,
                        TabContentDirective,
                        ChartWizardPropertyPaneChartTabComponent,
                        ChartWizardPropertyPaneFormatTabComponent,
                        ChartWizardPropertyPaneDataTabComponent,
                        WatermarkOverlayComponent,
                        LocalizedMessagesDirective
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }, { type: StateService }]; }, propDecorators: { data: [{
                type: Input
            }], defaultState: [{
                type: Input
            }], exportOptions: [{
                type: Input
            }], collapsedConfigurationPane: [{
                type: Input
            }], windowSettings: [{
                type: Input
            }], close: [{
                type: Output
            }], export: [{
                type: Output
            }], dir: [{
                type: HostBinding,
                args: ['attr.dir']
            }], chart: [{
                type: ViewChild,
                args: [ChartComponent]
            }], propertyPane: [{
                type: ViewChild,
                args: [ChartWizardPropertyPaneChartTabComponent]
            }], dataTab: [{
                type: ViewChild,
                args: [ChartWizardPropertyPaneDataTabComponent]
            }] } });

const getWizardDataFromDataRows = ChartWizardCommon.getWizardDataFromDataRows;

/**
 * Maps the Grid selectedKeys to a more general DataRows type to be displayed in the Chart Wizard.
 *
 * The selectedKeys can be either row keys or cell keys.
 *
 * @returns DataRow array that can be passed to getWizardDataFromDataRows in order to bind the Chart Wizard.
 */
function getGridSelectedRows(args) {
    const { grid, data, selectedKeys, selectionKey, columnKey } = args;
    const columns = [...grid.leafColumns];
    const allColumns = columns.map((column) => ({ field: column.field, title: column.title }));
    const selectedColumns = new Map();
    let getItemByKey;
    if (selectionKey) {
        const idGetter = getter(selectionKey);
        const dataMap = new Map(data.map((item) => [idGetter(item), item]));
        getItemByKey = itemKey => dataMap.get(itemKey);
    }
    else {
        getItemByKey = itemIndex => data[itemIndex];
    }
    let getColumnByColumnKey = key => columns[key];
    if (typeof columnKey === "function") {
        const columnMap = new Map(columns.map((col, colIndex) => [columnKey(col, colIndex), col]));
        getColumnByColumnKey = key => columnMap.get(key);
    }
    selectedKeys.forEach(item => {
        if (isPresent(item.columnKey)) {
            const itemColumns = selectedColumns.get(item.itemKey) || [];
            const column = getColumnByColumnKey(item.columnKey);
            const columnIndex = columns.indexOf(column);
            const dataColumn = { field: column.field, title: column.title };
            itemColumns.splice(columnIndex, 0, dataColumn);
            selectedColumns.set(item.itemKey, itemColumns);
        }
        else {
            selectedColumns.set(item, allColumns);
        }
    });
    return [...selectedColumns.entries()].map(([itemKey, dataColumns]) => ({
        dataItem: getItemByKey(itemKey),
        dataColumns
    }));
}

/**
 * Maps the Grid selectedKeys to data to be displayed in the Chart Wizard.
 *
 * Supports both row and cell selection.
 * @returns collection that can be used as Chart Wizard.
*/
const getWizardDataFromGridSelection = (args) => getWizardDataFromDataRows(getGridSelectedRows(args));

/**
 * A directive which binds the Chart Wizard from the selection state of the Grid
 * ([see example](slug:grid_integration_with_chart).
 */
class ChartWizardGridBindingDirective {
    grid;
    /**
     * Defines the collection that will store the Chart Wizard data.
     *
     * @default []
     */
    chartWizardData = [];
    /**
     * Fires when the `chartWizardData` collection has been updated.
     */
    chartWizardDataChange = new EventEmitter();
    /**
     * @hidden
     */
    data;
    /**
     * @hidden
     */
    selectionKey;
    /**
     * @hidden
     */
    columnKey;
    constructor(grid) {
        this.grid = grid;
    }
    ngOnInit() {
        if (!this.selectionKey || !this.data) {
            throw new Error('The [kendoChartWizardGridBinding] directive requires that [kendoGridBinding] and [kendoGridSelectBy] are set. ' +
                'See the Grid documentation for an example on how to use the Chart Wizard without the directive.');
        }
        if (typeof this.selectionKey === 'function') {
            throw new Error('The [kendoChartWizardGridBinding] directive supports only strings as [kendoGridSelectBy] selection key.');
        }
    }
    onSelectionChange(selectedKeys) {
        this.chartWizardData = getWizardDataFromGridSelection({
            grid: this.grid,
            data: this.data,
            selectedKeys,
            selectionKey: this.selectionKey
        });
        this.chartWizardDataChange.emit(this.chartWizardData);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardGridBindingDirective, deps: [{ token: i1$1.GridComponent }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: ChartWizardGridBindingDirective, isStandalone: true, selector: "[kendoChartWizardGridBinding]", inputs: { chartWizardData: "chartWizardData", data: ["kendoGridBinding", "data"], selectionKey: ["kendoGridSelectBy", "selectionKey"], columnKey: "columnKey" }, outputs: { chartWizardDataChange: "chartWizardDataChange" }, host: { listeners: { "selectedKeysChange": "onSelectionChange($event)" } }, exportAs: ["kendoChartWizardGridBinding"], ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardGridBindingDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoChartWizardGridBinding]',
                    exportAs: 'kendoChartWizardGridBinding',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$1.GridComponent }]; }, propDecorators: { chartWizardData: [{
                type: Input
            }], chartWizardDataChange: [{
                type: Output
            }], data: [{
                type: Input,
                args: ['kendoGridBinding']
            }], selectionKey: [{
                type: Input,
                args: ['kendoGridSelectBy']
            }], columnKey: [{
                type: Input
            }], onSelectionChange: [{
                type: HostListener,
                args: ['selectedKeysChange', ['$event']]
            }] } });

/**
 * Custom component messages override default component messages.
 * @example
 * ```html
 *  <kendo-chartwizard [data]="data">
 *      <kendo-chartwizard-messages
 *          windowTitle="Title"
 *      ></kendo-chartwizard-messages>
 *  </kendo-chartwizard>
 * ```
 */
class CustomMessagesComponent extends Messages {
    service;
    constructor(service) {
        super();
        this.service = service;
    }
    get override() {
        return true;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomMessagesComponent, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CustomMessagesComponent, isStandalone: true, selector: "kendo-chartwizard-messages", providers: [
            {
                provide: Messages,
                useExisting: forwardRef(() => CustomMessagesComponent)
            }
        ], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomMessagesComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [
                        {
                            provide: Messages,
                            useExisting: forwardRef(() => CustomMessagesComponent)
                        }
                    ],
                    selector: 'kendo-chartwizard-messages',
                    template: ``,
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; } });

/**
 * Utility array that contains all `@progress/kendo-angular-chart-wizard` related components and directives.
 */
const KENDO_CHARTWIZARD = [
    ChartWizardComponent,
    ChartWizardGridBindingDirective,
    CustomMessagesComponent
];

//IMPORTANT: NgModule export kept for backwards compatibility
/**
 * A [module](link:site.data.urls.angular['ngmoduleapi']) that includes the Chart Wizard component and directives.
 *
 * Imports the ChartWizardModule into your application
 * [root module](link:site.data.urls.angular['ngmodules']#angular-modularity) or any other sub-module
 * that will use the Chart Wizard component.
 */
class ChartWizardModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardModule, imports: [ChartWizardComponent, ChartWizardGridBindingDirective, CustomMessagesComponent], exports: [ChartWizardComponent, ChartWizardGridBindingDirective, CustomMessagesComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardModule, providers: [
            ThemeService,
            PopupService,
            ResizeBatchService,
            IconsService,
            DialogContainerService,
            DialogService,
            WindowService,
            WindowContainerService
        ], imports: [ChartWizardComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ChartWizardModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [...KENDO_CHARTWIZARD],
                    exports: [...KENDO_CHARTWIZARD],
                    providers: [
                        ThemeService,
                        PopupService,
                        ResizeBatchService,
                        IconsService,
                        DialogContainerService,
                        DialogService,
                        WindowService,
                        WindowContainerService
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { ChartWizardComponent, ChartWizardGridBindingDirective, ChartWizardModule, CustomMessagesComponent, ExportEvent, KENDO_CHARTWIZARD, getGridSelectedRows, getWizardDataFromDataRows, getWizardDataFromGridSelection };

